@@ -3,9 +3,12 @@ package com.sun.tools.javac.resources;
 public final class javac_ja extends java.util.ListResourceBundle {
     protected final Object[][] getContents() {
         return new Object[][] {
+            { "javac.description", "Java\u30AF\u30E9\u30B9\u304A\u3088\u3073\u30A4\u30F3\u30BF\u30D5\u30A7\u30FC\u30B9\u306E\u5B9A\u7FA9\u3092\u8AAD\u307F\u53D6\u308A\u3001\u30D0\u30A4\u30C8\u30B3\u30FC\u30C9\u304A\u3088\u3073\u30AF\u30E9\u30B9\u30FB\u30D5\u30A1\u30A4\u30EB\u306B\u30B3\u30F3\u30D1\u30A4\u30EB\u3057\u307E\u3059" },
             { "javac.fullVersion", "{0}\u30D5\u30EB\u30FB\u30D0\u30FC\u30B8\u30E7\u30F3\"{1}\"" },
-            { "javac.msg.bug", "\u30B3\u30F3\u30D1\u30A4\u30E9\u3067\u4F8B\u5916\u304C\u767A\u751F\u3057\u307E\u3057\u305F({0})\u3002Bug Database (http://bugs.java.com)\u3067\u91CD\u8907\u304C\u306A\u3044\u304B\u3092\u3054\u78BA\u8A8D\u306E\u3046\u3048\u3001Java bug\u30EC\u30DD\u30FC\u30C8\u30FB\u30DA\u30FC\u30B8(http://bugreport.java.com)\u3067Java\u30B3\u30F3\u30D1\u30A4\u30E9\u306B\u5BFE\u3059\u308Bbug\u306E\u767B\u9332\u3092\u304A\u9858\u3044\u3044\u305F\u3057\u307E\u3059\u3002\u30EC\u30DD\u30FC\u30C8\u306B\u306F\u3001\u305D\u306E\u30D7\u30ED\u30B0\u30E9\u30E0\u3068\u4E0B\u8A18\u306E\u8A3A\u65AD\u5185\u5BB9\u3092\u542B\u3081\u3066\u304F\u3060\u3055\u3044\u3002\u3054\u5354\u529B\u3042\u308A\u304C\u3068\u3046\u3054\u3056\u3044\u307E\u3059\u3002" },
+            { "javac.msg.bug", "\u30B3\u30F3\u30D1\u30A4\u30E9\u3067\u4F8B\u5916\u304C\u767A\u751F\u3057\u307E\u3057\u305F({0})\u3002\u30D0\u30B0\u30FB\u30C7\u30FC\u30BF\u30D9\u30FC\u30B9(https://bugs.java.com)\u3067\u91CD\u8907\u304C\u306A\u3044\u304B\u3092\u3054\u78BA\u8A8D\u306E\u3046\u3048\u3001Java\u306E\u30D0\u30B0\u30FB\u30EC\u30DD\u30FC\u30C8\u30FB\u30DA\u30FC\u30B8(https://bugreport.java.com)\u304B\u3089\u3001Java\u30B3\u30F3\u30D1\u30A4\u30E9\u306B\u5BFE\u3059\u308B\u30D0\u30B0\u306E\u767B\u9332\u3092\u304A\u9858\u3044\u3044\u305F\u3057\u307E\u3059\u3002\u30EC\u30DD\u30FC\u30C8\u306B\u306F\u3001\u8A72\u5F53\u306E\u30D7\u30ED\u30B0\u30E9\u30E0\u3001\u6B21\u306E\u8A3A\u65AD\u5185\u5BB9\u3001\u304A\u3088\u3073Java\u30B3\u30F3\u30D1\u30A4\u30E9\u306B\u6E21\u3055\u308C\u305F\u30D1\u30E9\u30E1\u30FC\u30BF\u3092\u3054\u5165\u529B\u304F\u3060\u3055\u3044\u3002\u3054\u5354\u529B\u3042\u308A\u304C\u3068\u3046\u3054\u3056\u3044\u307E\u3059\u3002" },
             { "javac.msg.io", "\n\n\u5165\u51FA\u529B\u30A8\u30E9\u30FC\u304C\u767A\u751F\u3057\u307E\u3057\u305F\u3002\n\u8A73\u7D30\u306F\u6B21\u306E\u30B9\u30BF\u30C3\u30AF\u30C8\u30EC\u30FC\u30B9\u3067\u8ABF\u67FB\u3057\u3066\u304F\u3060\u3055\u3044\u3002\n" },
+            { "javac.msg.parameters.output", "javac\u30D1\u30E9\u30E1\u30FC\u30BF\u3092\u6B21\u306E\u5834\u6240\u306B\u51FA\u529B\u3057\u3066\u3044\u307E\u3059: {0}" },
+            { "javac.msg.parameters.output.error", "javac\u30D1\u30E9\u30E1\u30FC\u30BF\u3092{0}\u306B\u51FA\u529B\u3057\u3088\u3046\u3068\u3057\u305F\u3068\u304D\u306B\u30A8\u30E9\u30FC\u304C\u767A\u751F\u3057\u307E\u3057\u305F\u3002\u30D1\u30E9\u30E1\u30FC\u30BF\u304C\u7D9A\u304D\u307E\u3059:" },
             { "javac.msg.plugin.uncaught.exception", "\n\n\u30D7\u30E9\u30B0\u30A4\u30F3\u3067\u6355\u6349\u3055\u308C\u306A\u3044\u4F8B\u5916\u304C\u30B9\u30ED\u30FC\u3055\u308C\u307E\u3057\u305F\u3002\n\u8A73\u7D30\u306F\u6B21\u306E\u30B9\u30BF\u30C3\u30AF\u30FB\u30C8\u30EC\u30FC\u30B9\u3067\u8ABF\u67FB\u3057\u3066\u304F\u3060\u3055\u3044\u3002\n" },
             { "javac.msg.proc.annotation.uncaught.exception", "\n\n\u6CE8\u91C8\u51E6\u7406\u3067\u6355\u6349\u3055\u308C\u306A\u3044\u4F8B\u5916\u304C\u30B9\u30ED\u30FC\u3055\u308C\u307E\u3057\u305F\u3002\n\u8A73\u7D30\u306F\u6B21\u306E\u30B9\u30BF\u30C3\u30AF\u30C8\u30EC\u30FC\u30B9\u3067\u8ABF\u67FB\u3057\u3066\u304F\u3060\u3055\u3044\u3002\n" },
             { "javac.msg.resource", "\n\n\u30B7\u30B9\u30C6\u30E0\u30FB\u30EA\u30BD\u30FC\u30B9\u304C\u4E0D\u8DB3\u3057\u3066\u3044\u307E\u3059\u3002\n\u8A73\u7D30\u306F\u6B21\u306E\u30B9\u30BF\u30C3\u30AF\u30C8\u30EC\u30FC\u30B9\u3067\u8ABF\u67FB\u3057\u3066\u304F\u3060\u3055\u3044\u3002\n" },
@@ -22,14 +25,15 @@ public final class javac_ja extends java.util.ListResourceBundle {
             { "javac.opt.Xdoclint", "javadoc\u30B3\u30E1\u30F3\u30C8\u306E\u554F\u984C\u306B\u95A2\u3059\u308B\u63A8\u5968\u30C1\u30A7\u30C3\u30AF\u3092\u6709\u52B9\u306B\u3057\u307E\u3059" },
             { "javac.opt.Xdoclint.custom", "javadoc\u30B3\u30E1\u30F3\u30C8\u306E\u554F\u984C\u306B\u95A2\u3059\u308B\u7279\u5B9A\u306E\u30C1\u30A7\u30C3\u30AF\u3092\u6709\u52B9\u307E\u305F\u306F\u7121\u52B9\u306B\u3057\u307E\u3059\u3002\n        \u3053\u3053\u3067\u3001<group>\u306Faccessibility\u3001html\u3001missing\u3001reference\u307E\u305F\u306Fsyntax\u306E\u3044\u305A\u308C\u304B\u3067\u3001\n        <access>\u306Fpublic\u3001protected\u3001package\u307E\u305F\u306Fprivate\u306E\u3044\u305A\u308C\u304B\u3067\u3059\u3002" },
             { "javac.opt.Xdoclint.package.args", "[-]<packages>(,[-]<package>)*" },
-            { "javac.opt.Xdoclint.package.desc", "\u7279\u5B9A\u306E\u30D1\u30C3\u30B1\u30FC\u30B8\u306E\u30C1\u30A7\u30C3\u30AF\u3092\u6709\u52B9\u307E\u305F\u306F\u7121\u52B9\u306B\u3057\u307E\u3059\u3002\u5404<package>\u306F\u3001\n\u30D1\u30C3\u30B1\u30FC\u30B8\u306E\u4FEE\u98FE\u3055\u308C\u305F\u540D\u524D\u3001\u307E\u305F\u306F\u30D1\u30C3\u30B1\u30FC\u30B8\u540D\u306E\u63A5\u982D\u8F9E\u306E\u5F8C\u306B''.*''\u3092\u6307\u5B9A\n(\u6307\u5B9A\u3057\u305F\u30D1\u30C3\u30B1\u30FC\u30B8\u306E\u3059\u3079\u3066\u306E\u30B5\u30D6\u30D1\u30C3\u30B1\u30FC\u30B8\u306B\u62E1\u5F35)\u3057\u305F\u3082\u306E\u3067\u3059\u3002\u5404<package>\u306E\u524D\u306B\n'-'\u3092\u6307\u5B9A\u3059\u308B\u3068\u3001\u6307\u5B9A\u3057\u305F1\u3064\u4EE5\u4E0A\u306E\u30D1\u30C3\u30B1\u30FC\u30B8\u306B\u95A2\u3059\u308B\u30C1\u30A7\u30C3\u30AF\u3092\u7121\u52B9\u306B\u3067\u304D\u307E\u3059\u3002" },
+            { "javac.opt.Xdoclint.package.desc", "\u7279\u5B9A\u306E\u30D1\u30C3\u30B1\u30FC\u30B8\u306E\u30C1\u30A7\u30C3\u30AF\u3092\u6709\u52B9\u307E\u305F\u306F\u7121\u52B9\u306B\u3057\u307E\u3059\u3002\u5404<package>\u306F\u3001\n\u4FEE\u98FE\u3055\u308C\u305F\u30D1\u30C3\u30B1\u30FC\u30B8\u540D\u3001\u307E\u305F\u306F\u30D1\u30C3\u30B1\u30FC\u30B8\u540D\u306E\u63A5\u982D\u8F9E\u306E\u5F8C\u306B''.*''\u3092\n\u6307\u5B9A(\u6307\u5B9A\u3057\u305F\u30D1\u30C3\u30B1\u30FC\u30B8\u306E\u3059\u3079\u3066\u306E\u30B5\u30D6\u30D1\u30C3\u30B1\u30FC\u30B8\u306B\u62E1\u5F35)\u3057\u305F\u3082\u306E\u3067\u3059\u3002\u5404<package>\n\u306E\u524D\u306B''-''\u3092\u6307\u5B9A\u3059\u308B\u3068\u3001\u6307\u5B9A\u3057\u305F1\u3064\u4EE5\u4E0A\u306E\u30D1\u30C3\u30B1\u30FC\u30B8\u306B\u95A2\u3059\u308B\u30C1\u30A7\u30C3\u30AF\u3092\u7121\u52B9\u306B\u3067\u304D\u307E\u3059\u3002" },
             { "javac.opt.Xdoclint.subopts", "(all|none|[-]<group>)[/<access>]" },
             { "javac.opt.Xlint", "\u63A8\u5968\u306E\u8B66\u544A\u3092\u6709\u52B9\u306B\u3059\u308B" },
             { "javac.opt.Xlint.all", "\u3059\u3079\u3066\u306E\u8B66\u544A\u3092\u6709\u52B9\u306B\u3057\u307E\u3059" },
-            { "javac.opt.Xlint.custom", "\u6709\u52B9\u307E\u305F\u306F\u7121\u52B9\u306B\u3059\u308B\u8B66\u544A(\u30AB\u30F3\u30DE\u533A\u5207\u308A)\u3002\n        \u6307\u5B9A\u3057\u305F\u8B66\u544A\u3092\u7121\u52B9\u306B\u3059\u308B\u306B\u306F\u3001\u30AD\u30FC\u306E\u524D\u306B'-'\u3092\u6307\u5B9A\u3057\u307E\u3059\u3002\n        \u30B5\u30DD\u30FC\u30C8\u3055\u308C\u3066\u3044\u308B\u30AD\u30FC\u306F\u6B21\u306E\u3068\u304A\u308A\u3067\u3059:" },
+            { "javac.opt.Xlint.custom", "\u6709\u52B9\u307E\u305F\u306F\u7121\u52B9\u306B\u3059\u308B\u8B66\u544A(\u30AB\u30F3\u30DE\u533A\u5207\u308A)\u3002\n\u6307\u5B9A\u3057\u305F\u8B66\u544A\u3092\u7121\u52B9\u306B\u3059\u308B\u306B\u306F\u3001\u30AD\u30FC\u306E\u524D\u306B''-''\u3092\u6307\u5B9A\u3057\u307E\u3059\u3002\n\u30B5\u30DD\u30FC\u30C8\u3055\u308C\u3066\u3044\u308B\u30AD\u30FC\u3092\u8868\u793A\u3059\u308B\u306B\u306F--help-lint\u3092\u4F7F\u7528\u3057\u307E\u3059\u3002" },
             { "javac.opt.Xlint.desc.auxiliaryclass", "\u30BD\u30FC\u30B9\u30FB\u30D5\u30A1\u30A4\u30EB\u3067\u975E\u8868\u793A\u306B\u306A\u3063\u3066\u3044\u308B\u304C\u4ED6\u306E\u30D5\u30A1\u30A4\u30EB\u304B\u3089\u4F7F\u7528\u3055\u308C\u3066\u3044\u308B\u88DC\u52A9\u30AF\u30E9\u30B9\u306B\u3064\u3044\u3066\u8B66\u544A\u3057\u307E\u3059\u3002" },
             { "javac.opt.Xlint.desc.cast", "\u4E0D\u8981\u306A\u30AD\u30E3\u30B9\u30C8\u306E\u4F7F\u7528\u306B\u3064\u3044\u3066\u8B66\u544A\u3057\u307E\u3059\u3002" },
             { "javac.opt.Xlint.desc.classfile", "\u30AF\u30E9\u30B9\u30FB\u30D5\u30A1\u30A4\u30EB\u306E\u5185\u5BB9\u306B\u95A2\u9023\u3057\u305F\u554F\u984C\u306B\u3064\u3044\u3066\u8B66\u544A\u3057\u307E\u3059\u3002" },
+            { "javac.opt.Xlint.desc.dangling-doc-comments", "\u3069\u306E\u5BA3\u8A00\u306B\u3082\u6DFB\u4ED8\u3055\u308C\u3066\u3044\u306A\u3044\u30C9\u30AD\u30E5\u30E1\u30F3\u30C6\u30FC\u30B7\u30E7\u30F3\u30FB\u30B3\u30E1\u30F3\u30C8\u306B\u3064\u3044\u3066\u8B66\u544A\u3057\u307E\u3059\u3002" },
             { "javac.opt.Xlint.desc.dep-ann", "JavaDoc\u3067\u975E\u63A8\u5968\u3068\u3057\u3066\u30DE\u30FC\u30AF\u3055\u308C\u3066\u3044\u308B\u304C@\u975E\u63A8\u5968\u306E\u6CE8\u91C8\u3092\u4F7F\u7528\u3057\u3066\u3044\u306A\u3044\u9805\u76EE\u306B\u3064\u3044\u3066\u8B66\u544A\u3057\u307E\u3059\u3002" },
             { "javac.opt.Xlint.desc.deprecation", "\u975E\u63A8\u5968\u9805\u76EE\u306E\u4F7F\u7528\u306B\u3064\u3044\u3066\u8B66\u544A\u3057\u307E\u3059\u3002" },
             { "javac.opt.Xlint.desc.divzero", "\u5B9A\u6574\u65700\u3067\u9664\u7B97\u3055\u308C\u308B\u3053\u3068\u306B\u3064\u3044\u3066\u8B66\u544A\u3057\u307E\u3059\u3002" },
@@ -37,9 +41,13 @@ public final class javac_ja extends java.util.ListResourceBundle {
             { "javac.opt.Xlint.desc.exports", "\u30E2\u30B8\u30E5\u30FC\u30EB\u306E\u30A8\u30AF\u30B9\u30DD\u30FC\u30C8\u306B\u95A2\u3059\u308B\u554F\u984C\u306B\u3064\u3044\u3066\u8B66\u544A\u3057\u307E\u3059\u3002" },
             { "javac.opt.Xlint.desc.fallthrough", "switch\u6587\u306E1\u3064\u306Ecase\u304B\u3089\u6B21\u3078\u306E\u30D5\u30A9\u30FC\u30EB\u30FB\u30B9\u30EB\u30FC\u306B\u3064\u3044\u3066\u8B66\u544A\u3057\u307E\u3059\u3002" },
             { "javac.opt.Xlint.desc.finally", "\u6B63\u5E38\u306B\u5B8C\u4E86\u3057\u306A\u3044finally\u7BC0\u306B\u3064\u3044\u3066\u8B66\u544A\u3057\u307E\u3059\u3002" },
+            { "javac.opt.Xlint.desc.incubating", "\u5B9F\u9A13\u7684\u306A\u30E2\u30B8\u30E5\u30FC\u30EB\u306E\u4F7F\u7528\u306B\u3064\u3044\u3066\u8B66\u544A\u3057\u307E\u3059\u3002" },
+            { "javac.opt.Xlint.desc.lossy-conversions", "\u8907\u5408\u4EE3\u5165\u306B\u304A\u3051\u308B\u7CBE\u5EA6\u304C\u5931\u308F\u308C\u308B\u53EF\u80FD\u6027\u304C\u3042\u308B\u5909\u63DB\u306B\u3064\u3044\u3066\u306E\u8B66\u544A\u3002" },
+            { "javac.opt.Xlint.desc.missing-explicit-ctor", "\u30A8\u30AF\u30B9\u30DD\u30FC\u30C8\u3055\u308C\u305F\u30D1\u30C3\u30B1\u30FC\u30B8\u306Epublic\u304A\u3088\u3073protected\u306E\u30AF\u30E9\u30B9\u306B\u660E\u793A\u7684\u306A\u30B3\u30F3\u30B9\u30C8\u30E9\u30AF\u30BF\u304C\u306A\u3044\u3053\u3068\u3092\u8B66\u544A\u3057\u307E\u3059\u3002" },
             { "javac.opt.Xlint.desc.module", "\u30E2\u30B8\u30E5\u30FC\u30EB\u30FB\u30B7\u30B9\u30C6\u30E0\u95A2\u9023\u306E\u554F\u984C\u306B\u3064\u3044\u3066\u8B66\u544A\u3057\u307E\u3059\u3002" },
             { "javac.opt.Xlint.desc.opens", "\u30E2\u30B8\u30E5\u30FC\u30EB\u306E\u30AA\u30FC\u30D7\u30F3\u306B\u95A2\u3059\u308B\u554F\u984C\u306B\u3064\u3044\u3066\u8B66\u544A\u3057\u307E\u3059\u3002" },
             { "javac.opt.Xlint.desc.options", "\u30B3\u30DE\u30F3\u30C9\u884C\u30AA\u30D7\u30B7\u30E7\u30F3\u306E\u4F7F\u7528\u306B\u95A2\u3059\u308B\u554F\u984C\u306B\u3064\u3044\u3066\u8B66\u544A\u3057\u307E\u3059\u3002" },
+            { "javac.opt.Xlint.desc.output-file-clash", "\u51FA\u529B\u30D5\u30A1\u30A4\u30EB\u304C\u30B3\u30F3\u30D1\u30A4\u30EB\u4E2D\u306B\u4E0A\u66F8\u304D\u3055\u308C\u305F\u5834\u5408\u306B\u8B66\u544A\u3057\u307E\u3059\u3002\u3053\u308C\u306F\u5927/\u5C0F\u6587\u5B57\u304C\u533A\u5225\u3055\u308C\u306A\u3044\n                         \u30D5\u30A1\u30A4\u30EB\u30B7\u30B9\u30C6\u30E0\u306A\u3069\u3067\u767A\u751F\u3059\u308B\u53EF\u80FD\u6027\u304C\u3042\u308A\u307E\u3059\u3002\u30AF\u30E9\u30B9\u30FB\u30D5\u30A1\u30A4\u30EB\u3001\u30CD\u30A4\u30C6\u30A3\u30D6\u30FB\u30D8\u30C3\u30C0\u30FC\u30FB\u30D5\u30A1\u30A4\u30EB\u304A\u3088\u3073\u30BD\u30FC\u30B9\u30FB\u30D5\u30A1\u30A4\u30EB\u304C\u30AB\u30D0\u30FC\u3055\u308C\u307E\u3059\u3002" },
             { "javac.opt.Xlint.desc.overloads", "\u30E1\u30BD\u30C3\u30C9\u306E\u30AA\u30FC\u30D0\u30FC\u30ED\u30FC\u30C9\u306B\u95A2\u3059\u308B\u554F\u984C\u306B\u3064\u3044\u3066\u8B66\u544A\u3057\u307E\u3059\u3002" },
             { "javac.opt.Xlint.desc.overrides", "\u30E1\u30BD\u30C3\u30C9\u306E\u30AA\u30FC\u30D0\u30FC\u30E9\u30A4\u30C9\u306B\u95A2\u3059\u308B\u554F\u984C\u306B\u3064\u3044\u3066\u8B66\u544A\u3057\u307E\u3059\u3002" },
             { "javac.opt.Xlint.desc.path", "\u30B3\u30DE\u30F3\u30C9\u884C\u306E\u7121\u52B9\u306A\u30D1\u30B9\u8981\u7D20\u306B\u3064\u3044\u3066\u8B66\u544A\u3057\u307E\u3059\u3002" },
@@ -49,15 +57,20 @@ public final class javac_ja extends java.util.ListResourceBundle {
             { "javac.opt.Xlint.desc.removal", "\u524A\u9664\u7528\u306B\u30DE\u30FC\u30AF\u3055\u308C\u305FAPI\u306E\u4F7F\u7528\u306B\u3064\u3044\u3066\u8B66\u544A\u3057\u307E\u3059\u3002" },
             { "javac.opt.Xlint.desc.requires-automatic", "requires\u53E5\u5185\u306E\u81EA\u52D5\u30E2\u30B8\u30E5\u30FC\u30EB\u306E\u4F7F\u7528\u306B\u3064\u3044\u3066\u8B66\u544A\u3057\u307E\u3059\u3002" },
             { "javac.opt.Xlint.desc.requires-transitive-automatic", "requires transitive\u5185\u306E\u81EA\u52D5\u30E2\u30B8\u30E5\u30FC\u30EB\u306B\u3064\u3044\u3066\u8B66\u544A\u3057\u307E\u3059\u3002" },
-            { "javac.opt.Xlint.desc.serial", "\u30B7\u30EA\u30A2\u30EB\u30FB\u30D0\u30FC\u30B8\u30E7\u30F3ID\u3092\u6307\u5B9A\u3057\u306A\u3044\u76F4\u5217\u5316\u53EF\u80FD\u306A\u30AF\u30E9\u30B9\u306B\u3064\u3044\u3066\u8B66\u544A\u3057\u307E\u3059\u3002 \n                             \u307E\u305F\u3001\u76F4\u5217\u5316\u53EF\u80FD\u8981\u7D20\u304B\u3089public\u4EE5\u5916\u306E\u30E1\u30F3\u30D0\u30FC\u3078\u306E\u30A2\u30AF\u30BB\u30B9\u306B\u3064\u3044\u3066\u8B66\u544A\u3057\u307E\u3059\u3002" },
+            { "javac.opt.Xlint.desc.restricted", "\u5236\u9650\u3055\u308C\u305F\u30E1\u30BD\u30C3\u30C9\u306E\u4F7F\u7528\u306B\u3064\u3044\u3066\u8B66\u544A\u3057\u307E\u3059\u3002" },
+            { "javac.opt.Xlint.desc.serial", "serialVersionUID\u30D5\u30A3\u30FC\u30EB\u30C9\u306E\u306A\u3044\u76F4\u5217\u5316\u53EF\u80FD\u30AF\u30E9\u30B9\u306B\u3064\u3044\u3066\u8B66\u544A\u3057\u307E\u3059\u3002 \n                         \u76F4\u5217\u5316\u53EF\u80FD\u304A\u3088\u3073\u5916\u90E8\u5316\u53EF\u80FD\u30AF\u30E9\u30B9\u3068\u30A4\u30F3\u30BF\u30D5\u30A7\u30FC\u30B9\u3067\u306E\u4ED6\u306E\u8981\u6CE8\u610F\u5BA3\u8A00\u306B\u3064\u3044\u3066\u3082\u8B66\u544A\u3057\u307E\u3059\u3002" },
             { "javac.opt.Xlint.desc.static", "\u30A4\u30F3\u30B9\u30BF\u30F3\u30B9\u3092\u4F7F\u7528\u3057\u305Fstatic\u30E1\u30F3\u30D0\u30FC\u3078\u306E\u30A2\u30AF\u30BB\u30B9\u306B\u3064\u3044\u3066\u8B66\u544A\u3057\u307E\u3059\u3002" },
+            { "javac.opt.Xlint.desc.strictfp", "strictfp\u4FEE\u98FE\u5B50\u306E\u4E0D\u8981\u306A\u4F7F\u7528\u306B\u3064\u3044\u3066\u8B66\u544A\u3057\u307E\u3059\u3002" },
+            { "javac.opt.Xlint.desc.synchronization", "\u5024\u30D9\u30FC\u30B9\u30FB\u30AF\u30E9\u30B9\u306E\u30A4\u30F3\u30B9\u30BF\u30F3\u30B9\u3067\u306E\u540C\u671F\u306E\u8A66\u884C\u306B\u3064\u3044\u3066\u8B66\u544A\u3057\u307E\u3059\u3002" },
+            { "javac.opt.Xlint.desc.text-blocks", "\u30C6\u30AD\u30B9\u30C8\u30FB\u30D6\u30ED\u30C3\u30AF\u30FB\u30A4\u30F3\u30C7\u30F3\u30C8\u5185\u306E\u4E00\u8CAB\u6027\u306E\u306A\u3044\u7A7A\u767D\u6587\u5B57\u306B\u3064\u3044\u3066\u8B66\u544A\u3057\u307E\u3059\u3002" },
+            { "javac.opt.Xlint.desc.this-escape", "\u5916\u90E8\u30B5\u30D6\u30AF\u30E9\u30B9\u3067\u30AA\u30FC\u30D0\u30FC\u30E9\u30A4\u30C9\u3055\u308C\u308B\u53EF\u80FD\u6027\u306E\u3042\u308B\u30E1\u30BD\u30C3\u30C9\u3092\u30B3\u30F3\u30B9\u30C8\u30E9\u30AF\u30BF\u304C\u547C\u3073\u51FA\u3057\u305F\u5834\u5408\u306B\u8B66\u544A\u3057\u307E\u3059\u3002\n                         \u3053\u306E\u3088\u3046\u306A\u30E1\u30BD\u30C3\u30C9\u306F\u3001\u30B5\u30D6\u30AF\u30E9\u30B9\u30FB\u30B3\u30F3\u30B9\u30C8\u30E9\u30AF\u30BF\u304C\u305D\u306E\u521D\u671F\u5316\u3092\u5B8C\u4E86\u3059\u308B\u524D\u306B\u5B9F\u884C\u3055\u308C\u307E\u3059\u3002" },
             { "javac.opt.Xlint.desc.try", "try\u30D6\u30ED\u30C3\u30AF(try-with-resources\u306A\u3069)\u306E\u4F7F\u7528\u306B\u95A2\u3059\u308B\u554F\u984C\u306B\u3064\u3044\u3066\u8B66\u544A\u3057\u307E\u3059\u3002" },
             { "javac.opt.Xlint.desc.unchecked", "\u7121\u691C\u67FB\u64CD\u4F5C\u306B\u3064\u3044\u3066\u8B66\u544A\u3057\u307E\u3059\u3002" },
             { "javac.opt.Xlint.desc.varargs", "\u5B89\u5168\u3067\u306F\u306A\u3044\u53EF\u80FD\u6027\u304C\u3042\u308B\u53EF\u5909\u5F15\u6570\u30E1\u30BD\u30C3\u30C9\u306B\u3064\u3044\u3066\u8B66\u544A\u3057\u307E\u3059" },
             { "javac.opt.Xlint.none", "\u3059\u3079\u3066\u306E\u8B66\u544A\u3092\u7121\u52B9\u306B\u3057\u307E\u3059" },
             { "javac.opt.Xstdout", "\u6A19\u6E96\u51FA\u529B\u3092\u30EA\u30C0\u30A4\u30EC\u30AF\u30C8\u3059\u308B" },
             { "javac.opt.addExports", "<other-module>\u304CALL-UNNAMED\u3067\u3042\u308B\u5834\u5408\u3001\u305D\u306E\u5B9A\u7FA9\u30E2\u30B8\u30E5\u30FC\u30EB\u304B\u3089\u3001\u8FFD\u52A0\u30E2\u30B8\u30E5\u30FC\u30EB\u307E\u305F\u306F\n        \u3059\u3079\u3066\u306E\u540D\u524D\u306E\u306A\u3044\u30E2\u30B8\u30E5\u30FC\u30EB\u306B\u30A8\u30AF\u30B9\u30DD\u30FC\u30C8\u6E08\u3068\u307F\u306A\u3055\u308C\u308B\u3088\u3046\u306B\u30D1\u30C3\u30B1\u30FC\u30B8\u3092\u6307\u5B9A\u3057\u307E\u3059\u3002" },
-            { "javac.opt.addReads", "\u6307\u5B9A\u306E\u30E2\u30B8\u30E5\u30FC\u30EB\u3067\u5FC5\u9808\u3068\u307F\u306A\u3055\u308C\u308B\u3088\u3046\u306B\u8FFD\u52A0\u30E2\u30B8\u30E5\u30FC\u30EB\u3092\u6307\u5B9A\u3057\u307E\u3059\u3002\n        \u540D\u524D\u306E\u306A\u3044\u30E2\u30B8\u30E5\u30FC\u30EB\u3092\u5FC5\u8981\u3068\u3059\u308B\u5834\u5408\u3001<other-module>\u306FALL-UNNAMED\u306B\u3057\u307E\u3059\u3002" },
+            { "javac.opt.addReads", "\u6307\u5B9A\u306E\u30E2\u30B8\u30E5\u30FC\u30EB\u3067\u5FC5\u9808\u3068\u307F\u306A\u3055\u308C\u308B\u3088\u3046\u306B\u8FFD\u52A0\u30E2\u30B8\u30E5\u30FC\u30EB\u3092\u6307\u5B9A\u3057\u307E\u3059\u3002\n\u540D\u524D\u306E\u306A\u3044\u30E2\u30B8\u30E5\u30FC\u30EB\u3092\u5FC5\u8981\u3068\u3059\u308B\u5834\u5408\u3001<other-module>\u306F\nALL-UNNAMED\u306B\u3057\u307E\u3059\u3002" },
             { "javac.opt.addmods", "\u521D\u671F\u30E2\u30B8\u30E5\u30FC\u30EB\u306B\u52A0\u3048\u3066\u89E3\u6C7A\u3059\u308B\u30EB\u30FC\u30C8\u30FB\u30E2\u30B8\u30E5\u30FC\u30EB\u3001\u307E\u305F\u306F<module>\u304C\n        ALL-MODULE-PATH\u3067\u3042\u308B\u5834\u5408\u306F\u30E2\u30B8\u30E5\u30FC\u30EB\u30FB\u30D1\u30B9\u306E\u3059\u3079\u3066\u306E\u30E2\u30B8\u30E5\u30FC\u30EB\u3002" },
             { "javac.opt.arg.Xlint", "<key>(,<key>)*" },
             { "javac.opt.arg.addExports", "<module>/<package>=<other-module>(,<other-module>)*" },
@@ -91,7 +104,6 @@ public final class javac_ja extends java.util.ListResourceBundle {
             { "javac.opt.default.module.for.created.files", "\u4F55\u3082\u6307\u5B9A\u3055\u308C\u3066\u3044\u306A\u3044\u304B\u3001\u63A8\u5B9A\u578B\u306E\u5834\u5408\u3001\u6CE8\u91C8\u30D7\u30ED\u30BB\u30C3\u30B5\u306B\u3088\u3063\u3066\u4F5C\u6210\u3055\u308C\u308B\u30D5\u30A1\u30A4\u30EB\u306E\u30BF\u30FC\u30B2\u30C3\u30C8\u30FB\u30E2\u30B8\u30E5\u30FC\u30EB\u3092\u30D5\u30A9\u30FC\u30EB\u30D0\u30C3\u30AF\u3057\u307E\u3059\u3002" },
             { "javac.opt.deprecation", "\u63A8\u5968\u3055\u308C\u306A\u3044API\u304C\u4F7F\u7528\u3055\u308C\u3066\u3044\u308B\u30BD\u30FC\u30B9\u306E\u4F4D\u7F6E\u3092\u51FA\u529B\u3059\u308B" },
             { "javac.opt.diags", "\u8A3A\u65AD\u30E2\u30FC\u30C9\u306E\u9078\u629E" },
-            { "javac.opt.doclint.format", "\u30C9\u30AD\u30E5\u30E1\u30F3\u30C8\u30FB\u30B3\u30E1\u30F3\u30C8\u306E\u5F62\u5F0F\u3092\u6307\u5B9A\u3057\u307E\u3059" },
             { "javac.opt.encoding", "\u30BD\u30FC\u30B9\u30FB\u30D5\u30A1\u30A4\u30EB\u304C\u4F7F\u7528\u3059\u308B\u6587\u5B57\u30A8\u30F3\u30B3\u30FC\u30C7\u30A3\u30F3\u30B0\u3092\u6307\u5B9A\u3059\u308B" },
             { "javac.opt.endorseddirs", "\u63A8\u5968\u898F\u683C\u30D1\u30B9\u306E\u4F4D\u7F6E\u3092\u30AA\u30FC\u30D0\u30FC\u30E9\u30A4\u30C9\u3059\u308B" },
             { "javac.opt.extdirs", "\u30A4\u30F3\u30B9\u30C8\u30FC\u30EB\u6E08\u307F\u62E1\u5F35\u6A5F\u80FD\u306E\u4F4D\u7F6E\u3092\u30AA\u30FC\u30D0\u30FC\u30E9\u30A4\u30C9\u3059\u308B" },
@@ -100,9 +112,12 @@ public final class javac_ja extends java.util.ListResourceBundle {
             { "javac.opt.g.none", "\u30C7\u30D0\u30C3\u30B0\u60C5\u5831\u3092\u751F\u6210\u3057\u306A\u3044" },
             { "javac.opt.headerDest", "\u751F\u6210\u3055\u308C\u305F\u30CD\u30A4\u30C6\u30A3\u30D6\u30FB\u30D8\u30C3\u30C0\u30FC\u30FB\u30D5\u30A1\u30A4\u30EB\u3092\u683C\u7D0D\u3059\u308B\u5834\u6240\u3092\u6307\u5B9A\u3059\u308B" },
             { "javac.opt.help", "\u3053\u306E\u30D8\u30EB\u30D7\u30FB\u30E1\u30C3\u30BB\u30FC\u30B8\u3092\u51FA\u529B\u3057\u307E\u3059" },
+            { "javac.opt.help.lint", "-Xlint\u306B\u30B5\u30DD\u30FC\u30C8\u3055\u308C\u3066\u3044\u308B\u30AD\u30FC\u3092\u51FA\u529B\u3057\u307E\u3059" },
+            { "javac.opt.help.lint.header", "-Xlint\u306B\u30B5\u30DD\u30FC\u30C8\u3055\u308C\u3066\u3044\u308B\u30AD\u30FC\u306F\u6B21\u306E\u3068\u304A\u308A\u3067\u3059:" },
             { "javac.opt.implicit", "\u6697\u9ED9\u7684\u306B\u53C2\u7167\u3055\u308C\u308B\u30D5\u30A1\u30A4\u30EB\u306B\u3064\u3044\u3066\u30AF\u30E9\u30B9\u30FB\u30D5\u30A1\u30A4\u30EB\u3092\u751F\u6210\u3059\u308B\u304B\u3069\u3046\u304B\u3092\u6307\u5B9A\u3059\u308B" },
             { "javac.opt.inherit_runtime_environment", "\u5B9F\u884C\u6642\u74B0\u5883\u304B\u3089\u30E2\u30B8\u30E5\u30FC\u30EB\u30FB\u30B7\u30B9\u30C6\u30E0\u69CB\u6210\u30AA\u30D7\u30B7\u30E7\u30F3\u3092\u7D99\u627F\u3057\u307E\u3059\u3002" },
             { "javac.opt.limitmods", "\u53C2\u7167\u53EF\u80FD\u306A\u30E2\u30B8\u30E5\u30FC\u30EB\u306E\u9818\u57DF\u3092\u5236\u9650\u3057\u307E\u3059" },
+            { "javac.opt.lineDocComments", "''///''\u3067\u884C\u3092\u958B\u59CB\u3059\u308B\u3068\u3001\u30C9\u30AD\u30E5\u30E1\u30F3\u30C6\u30FC\u30B7\u30E7\u30F3\u30FB\u30B3\u30E1\u30F3\u30C8\u306E\u30B5\u30DD\u30FC\u30C8\u304C\u7121\u52B9\u5316\u3055\u308C\u307E\u3059" },
             { "javac.opt.m", "\u6307\u5B9A\u3057\u305F\u30E2\u30B8\u30E5\u30FC\u30EB\u306E\u307F\u30B3\u30F3\u30D1\u30A4\u30EB\u3057\u3001\u30BF\u30A4\u30E0\u30B9\u30BF\u30F3\u30D7\u3092\u78BA\u8A8D\u3059\u308B" },
             { "javac.opt.maxerrs", "\u51FA\u529B\u3059\u308B\u30A8\u30E9\u30FC\u306E\u6700\u5927\u6570\u3092\u8A2D\u5B9A\u3059\u308B" },
             { "javac.opt.maxwarns", "\u51FA\u529B\u3059\u308B\u8B66\u544A\u306E\u6700\u5927\u6570\u3092\u8A2D\u5B9A\u3059\u308B" },
@@ -127,15 +142,15 @@ public final class javac_ja extends java.util.ListResourceBundle {
             { "javac.opt.processor", "\u5B9F\u884C\u3059\u308B\u6CE8\u91C8\u30D7\u30ED\u30BB\u30C3\u30B5\u306E\u540D\u524D\u3002\u30C7\u30D5\u30A9\u30EB\u30C8\u306E\u691C\u51FA\u51E6\u7406\u3092\u30D0\u30A4\u30D1\u30B9" },
             { "javac.opt.processormodulepath", "\u6CE8\u91C8\u30D7\u30ED\u30BB\u30C3\u30B5\u3092\u691C\u7D22\u3059\u308B\u30E2\u30B8\u30E5\u30FC\u30EB\u30FB\u30D1\u30B9\u3092\u6307\u5B9A\u3059\u308B" },
             { "javac.opt.processorpath", "\u6CE8\u91C8\u30D7\u30ED\u30BB\u30C3\u30B5\u3092\u691C\u7D22\u3059\u308B\u4F4D\u7F6E\u3092\u6307\u5B9A\u3059\u308B" },
-            { "javac.opt.profile", "\u4F7F\u7528\u3055\u308C\u3066\u3044\u308BAPI\u304C\u6307\u5B9A\u3057\u305F\u30D7\u30ED\u30D5\u30A1\u30A4\u30EB\u3067\u4F7F\u7528\u53EF\u80FD\u304B\u3069\u3046\u304B\u3092\u78BA\u8A8D\u3057\u307E\u3059" },
+            { "javac.opt.profile", "\u4F7F\u7528\u3055\u308C\u3066\u3044\u308BAPI\u304C\u3001\u6307\u5B9A\u3057\u305F\u30D7\u30ED\u30D5\u30A1\u30A4\u30EB\u3067\u4F7F\u7528\u53EF\u80FD\u304B\u3069\u3046\u304B\u3092\u78BA\u8A8D\u3057\u307E\u3059\u3002\n\u3053\u306E\u30AA\u30D7\u30B7\u30E7\u30F3\u306F\u975E\u63A8\u5968\u3067\u3042\u308A\u3001\u4ECA\u5F8C\u306E\u30EA\u30EA\u30FC\u30B9\u3067\u524A\u9664\u3055\u308C\u308B\u53EF\u80FD\u6027\u304C\u3042\u308A\u307E\u3059\u3002" },
             { "javac.opt.prompt", "\u5404\u30A8\u30E9\u30FC\u3067\u505C\u6B62\u3059\u308B" },
-            { "javac.opt.release", "\u7279\u5B9A\u306E\u30EA\u30EA\u30FC\u30B9\u7528\u306B\u30B3\u30F3\u30D1\u30A4\u30EB\u3057\u307E\u3059\u3002\u30B5\u30DD\u30FC\u30C8\u3055\u308C\u3066\u3044\u308B\u30EA\u30EA\u30FC\u30B9: {0}" },
+            { "javac.opt.release", "\u6307\u5B9A\u3055\u308C\u305FJava SE\u30EA\u30EA\u30FC\u30B9\u306B\u5BFE\u3057\u3066\u30B3\u30F3\u30D1\u30A4\u30EB\u3057\u307E\u3059\u3002\u30B5\u30DD\u30FC\u30C8\u3055\u308C\u3066\u3044\u308B\u30EA\u30EA\u30FC\u30B9: \n    {0}" },
             { "javac.opt.s", "\u30AF\u30E9\u30B9\u30FB\u30D5\u30A1\u30A4\u30EB\u306E\u304B\u308F\u308A\u306Bjava\u30BD\u30FC\u30B9\u3092\u767A\u884C\u3059\u308B" },
-            { "javac.opt.source", "\u6307\u5B9A\u3055\u308C\u305F\u30EA\u30EA\u30FC\u30B9\u3068\u30BD\u30FC\u30B9\u306E\u4E92\u63DB\u6027\u3092\u4FDD\u6301\u3057\u307E\u3059\u3002\u30B5\u30DD\u30FC\u30C8\u3055\u308C\u3066\u3044\u308B\u30EA\u30EA\u30FC\u30B9: {0}" },
+            { "javac.opt.source", "\u6307\u5B9A\u3055\u308C\u305FJava SE\u30EA\u30EA\u30FC\u30B9\u3068\u30BD\u30FC\u30B9\u306E\u4E92\u63DB\u6027\u3092\u4FDD\u6301\u3057\u307E\u3059\u3002\u30B5\u30DD\u30FC\u30C8\u3055\u308C\u3066\u3044\u308B\u30EA\u30EA\u30FC\u30B9: \n    {0}" },
             { "javac.opt.sourceDest", "\u751F\u6210\u3055\u308C\u305F\u30BD\u30FC\u30B9\u30FB\u30D5\u30A1\u30A4\u30EB\u3092\u683C\u7D0D\u3059\u308B\u5834\u6240\u3092\u6307\u5B9A\u3059\u308B" },
             { "javac.opt.sourcepath", "\u5165\u529B\u30BD\u30FC\u30B9\u30FB\u30D5\u30A1\u30A4\u30EB\u3092\u691C\u7D22\u3059\u308B\u4F4D\u7F6E\u3092\u6307\u5B9A\u3059\u308B" },
             { "javac.opt.system", "\u30B7\u30B9\u30C6\u30E0\u30FB\u30E2\u30B8\u30E5\u30FC\u30EB\u306E\u4F4D\u7F6E\u3092\u30AA\u30FC\u30D0\u30FC\u30E9\u30A4\u30C9\u3059\u308B" },
-            { "javac.opt.target", "\u7279\u5B9A\u306EVM\u30D0\u30FC\u30B8\u30E7\u30F3\u7528\u306E\u30AF\u30E9\u30B9\u30FB\u30D5\u30A1\u30A4\u30EB\u3092\u751F\u6210\u3057\u307E\u3059\u3002\u30B5\u30DD\u30FC\u30C8\u3055\u308C\u3066\u3044\u308B\u30D0\u30FC\u30B8\u30E7\u30F3: {0}" },
+            { "javac.opt.target", "\u6307\u5B9A\u3055\u308C\u305FJava SE\u30EA\u30EA\u30FC\u30B9\u306B\u9069\u3057\u305F\u30AF\u30E9\u30B9\u30FB\u30D5\u30A1\u30A4\u30EB\u3092\u751F\u6210\u3057\u307E\u3059\u3002\u30B5\u30DD\u30FC\u30C8\u3055\u308C\u3066\u3044\u308B\u30EA\u30EA\u30FC\u30B9: \n    {0}" },
             { "javac.opt.upgrademodulepath", "\u30A2\u30C3\u30D7\u30B0\u30EC\u30FC\u30C9\u53EF\u80FD\u306A\u30E2\u30B8\u30E5\u30FC\u30EB\u306E\u4F4D\u7F6E\u3092\u30AA\u30FC\u30D0\u30FC\u30E9\u30A4\u30C9\u3059\u308B" },
             { "javac.opt.userpathsfirst", "\u30D6\u30FC\u30C8\u30FB\u30AF\u30E9\u30B9\u30D1\u30B9\u306E\u5F8C\u3067\u306F\u306A\u304F\u3001\u30D6\u30FC\u30C8\u30FB\u30AF\u30E9\u30B9\u30D1\u30B9\u306E\u524D\u306B\u30AF\u30E9\u30B9\u306E\u30AF\u30E9\u30B9\u30D1\u30B9\u304A\u3088\u3073\u30BD\u30FC\u30B9\u30FB\u30D1\u30B9\u3092\u691C\u7D22\u3059\u308B" },
             { "javac.opt.verbose", "\u30B3\u30F3\u30D1\u30A4\u30E9\u306E\u52D5\u4F5C\u306B\u3064\u3044\u3066\u30E1\u30C3\u30BB\u30FC\u30B8\u3092\u51FA\u529B\u3059\u308B" },
