@@ -3,9 +3,9 @@ package com.sun.tools.javac.resources;
 public final class version extends java.util.ListResourceBundle {
     protected final Object[][] getContents() {
         return new Object[][] {
-            { "full", "23" },
-            { "jdk", "23" },
-            { "release", "23" },
+            { "full", "24.0.2" },
+            { "jdk", "24.0.2" },
+            { "release", "24.0.2" },
         };
     }
 }
