@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2015, 2020, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2015, 2024, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -34,6 +34,7 @@ import java.io.InputStream;
 import java.io.InterruptedIOException;
 import java.io.OutputStream;
 import java.io.PrintStream;
+import java.io.Writer;
 import java.net.URI;
 import java.nio.charset.Charset;
 import java.time.Instant;
@@ -45,9 +46,15 @@ import java.util.HashMap;
 import java.util.Iterator;
 import java.util.List;
 import java.util.ListIterator;
+import java.util.Locale;
 import java.util.Map;
 import java.util.Optional;
+import java.util.Set;
+import java.util.concurrent.ExecutorService;
+import java.util.concurrent.Executors;
+import java.util.function.Consumer;
 import java.util.function.Function;
+import java.util.regex.Pattern;
 import java.util.stream.Collectors;
 import java.util.stream.Stream;
 import java.util.stream.StreamSupport;
@@ -63,6 +70,7 @@ import jdk.internal.org.jline.keymap.KeyMap;
 import jdk.internal.org.jline.reader.Binding;
 import jdk.internal.org.jline.reader.EOFError;
 import jdk.internal.org.jline.reader.EndOfFileException;
+import jdk.internal.org.jline.reader.Highlighter;
 import jdk.internal.org.jline.reader.History;
 import jdk.internal.org.jline.reader.LineReader;
 import jdk.internal.org.jline.reader.LineReader.Option;
@@ -79,20 +87,29 @@ import jdk.internal.org.jline.terminal.Attributes.LocalFlag;
 import jdk.internal.org.jline.terminal.Size;
 import jdk.internal.org.jline.terminal.Terminal;
 import jdk.internal.org.jline.terminal.TerminalBuilder;
+import jdk.internal.org.jline.utils.AttributedString;
+import jdk.internal.org.jline.utils.AttributedStringBuilder;
+import jdk.internal.org.jline.utils.AttributedStyle;
 import jdk.internal.org.jline.utils.Display;
 import jdk.internal.org.jline.utils.NonBlocking;
 import jdk.internal.org.jline.utils.NonBlockingInputStreamImpl;
 import jdk.internal.org.jline.utils.NonBlockingReader;
+import jdk.internal.org.jline.utils.OSUtils;
 import jdk.jshell.ExpressionSnippet;
 import jdk.jshell.Snippet;
 import jdk.jshell.Snippet.SubKind;
+import jdk.jshell.SourceCodeAnalysis.Attribute;
 import jdk.jshell.SourceCodeAnalysis.CompletionInfo;
+import jdk.jshell.SourceCodeAnalysis.Highlight;
 import jdk.jshell.VarSnippet;
 
+import static java.nio.charset.StandardCharsets.UTF_8;
+
 class ConsoleIOContext extends IOContext {
 
     private static final String HISTORY_LINE_PREFIX = "HISTORY_LINE_";
 
+    private final ExecutorService backgroundWork = Executors.newFixedThreadPool(1);
     final boolean allowIncompleteInputs;
     final JShellTool repl;
     final StopDetectingInputStream input;
@@ -103,8 +120,8 @@ class ConsoleIOContext extends IOContext {
 
     String prefix = "";
 
-    ConsoleIOContext(JShellTool repl, InputStream cmdin, PrintStream cmdout) throws Exception {
-        this.allowIncompleteInputs = Boolean.getBoolean("jshell.test.allow.incomplete.inputs");
+    ConsoleIOContext(JShellTool repl, InputStream cmdin, PrintStream cmdout,
+                     boolean interactive, Size size) throws Exception {
         this.repl = repl;
         Map<String, Object> variables = new HashMap<>();
         this.input = new StopDetectingInputStream(() -> repl.stop(),
@@ -116,79 +133,58 @@ class ConsoleIOContext extends IOContext {
             }
         };
         Terminal terminal;
-        if (System.getProperty("test.jdk") != null) {
-            terminal = new TestTerminal(nonBlockingInput, cmdout);
+        boolean allowIncompleteInputs = Boolean.getBoolean("jshell.test.allow.incomplete.inputs");
+        Consumer<LineReaderImpl> setupReader = r -> {};
+        boolean useComplexDeprecationHighlight = false;
+        if (cmdin != System.in) {
+            boolean enableHighlighter;
+            setupReader = r -> {};
+            if (System.getProperty("test.jdk") != null) {
+                terminal = new TestTerminal(nonBlockingInput, cmdout);
+                enableHighlighter = Boolean.getBoolean("test.enable.highlighter");
+            } else {
+                terminal = new ProgrammaticInTerminal(nonBlockingInput, cmdout, interactive,
+                                                      size);
+                if (!interactive) {
+                    setupReader = setupReader.andThen(r -> r.unsetOpt(Option.BRACKETED_PASTE));
+                    allowIncompleteInputs = true;
+                }
+                enableHighlighter = interactive;
+            }
+            setupReader = setupReader.andThen(r -> r.option(Option.DISABLE_HIGHLIGHTER, !enableHighlighter));
             input.setInputStream(cmdin);
         } else {
-            terminal = TerminalBuilder.builder().inputStreamWrapper(in -> {
+            //on platforms which are known to be fully supported by
+            //the FFMTerminalProvider, do not permit the ExecTerminalProvider:
+            boolean allowExecTerminal = !OSUtils.IS_WINDOWS &&
+                                        !OSUtils.IS_LINUX &&
+                                        !OSUtils.IS_OSX;
+            terminal = TerminalBuilder.builder().exec(allowExecTerminal).inputStreamWrapper(in -> {
                 input.setInputStream(in);
                 return nonBlockingInput;
-            }).build();
+            }).nativeSignals(false).build();
+            useComplexDeprecationHighlight = !OSUtils.IS_WINDOWS;
         }
+        this.allowIncompleteInputs = allowIncompleteInputs;
         originalAttributes = terminal.getAttributes();
         Attributes noIntr = new Attributes(originalAttributes);
         noIntr.setControlChar(ControlChar.VINTR, 0);
         terminal.setAttributes(noIntr);
         terminal.enterRawMode();
-        LineReaderImpl reader = new LineReaderImpl(terminal, "jshell", variables) {
-            {
-                //jline can handle the CONT signal on its own, but (currently) requires sun.misc for it
-                try {
-                    Signal.handle(new Signal("CONT"), new Handler() {
-                        @Override public void handle(Signal sig) {
-                            try {
-                                handleSignal(jdk.internal.org.jline.terminal.Terminal.Signal.CONT);
-                            } catch (Exception ex) {
-                                ex.printStackTrace();
-                            }
-                        }
-                    });
-                } catch (IllegalArgumentException ignored) {
-                    //the CONT signal does not exist on this platform
-                }
-            }
-            CompletionState completionState = new CompletionState();
-            @Override
-            protected boolean doComplete(CompletionType lst, boolean useMenu, boolean prefix) {
-                return ConsoleIOContext.this.complete(completionState);
-            }
-            @Override
-            public Binding readBinding(KeyMap<Binding> keys, KeyMap<Binding> local) {
-                completionState.actionCount++;
-                return super.readBinding(keys, local);
-            }
-            @Override
-            protected boolean insertCloseParen() {
-                Object oldIndent = getVariable(INDENTATION);
-                try {
-                    setVariable(INDENTATION, 0);
-                    return super.insertCloseParen();
-                } finally {
-                    setVariable(INDENTATION, oldIndent);
-                }
-            }
-            @Override
-            protected boolean insertCloseSquare() {
-                Object oldIndent = getVariable(INDENTATION);
-                try {
-                    setVariable(INDENTATION, 0);
-                    return super.insertCloseSquare();
-                } finally {
-                    setVariable(INDENTATION, oldIndent);
-                }
-            }
-        };
+        LineReaderImpl reader = new JShellLineReader(terminal, "jshell", variables);
 
+        setupReader.accept(reader);
         reader.setOpt(Option.DISABLE_EVENT_EXPANSION);
 
         reader.setParser((line, cursor, context) -> {
-            if (!allowIncompleteInputs && !repl.isComplete(line)) {
+            if (!ConsoleIOContext.this.allowIncompleteInputs && !repl.isComplete(line)) {
                 int pendingBraces = countPendingOpenBraces(line);
                 throw new EOFError(cursor, cursor, line, null, pendingBraces, null);
             }
             return new ArgumentLine(line, cursor);
         });
 
+        reader.setHighlighter(new HighlighterImpl(useComplexDeprecationHighlight));
         reader.getKeyMaps().get(LineReader.MAIN)
               .bind((Widget) () -> fixes(), FIXES_SHORTCUT);
         reader.getKeyMaps().get(LineReader.MAIN)
@@ -230,7 +226,7 @@ class ConsoleIOContext extends IOContext {
         this.prefix = prefix;
         try {
             in.setVariable(LineReader.SECONDARY_PROMPT_PATTERN, continuationPrompt);
-            return in.readLine(firstLinePrompt);
+            return in.readLine(firstLine ? firstLinePrompt : continuationPrompt);
         } catch (UserInterruptException ex) {
             throw (InputInterruptedException) new InputInterruptedException().initCause(ex);
         } catch (EndOfFileException ex) {
@@ -247,8 +243,8 @@ class ConsoleIOContext extends IOContext {
     public Iterable<String> history(boolean currentSession) {
         return StreamSupport.stream(getHistory().spliterator(), false)
                             .filter(entry -> !currentSession || !historyLoad.equals(entry.time()))
-                            .map(entry -> entry.line())
-                            .collect(Collectors.toList());
+                            .map(History.Entry::line)
+                            .toList();
     }
 
     @Override
@@ -263,7 +259,7 @@ class ConsoleIOContext extends IOContext {
             StreamSupport.stream(in.getHistory().spliterator(), false)
                          .map(History.Entry::line)
                          .flatMap(this::toSplitEntries)
-                         .collect(Collectors.toList());
+                         .toList();
         if (!savedHistory.isEmpty()) {
             int len = (int) Math.ceil(Math.log10(savedHistory.size()+1));
             String format = HISTORY_LINE_PREFIX + "%0" + len + "d";
@@ -280,6 +276,7 @@ class ConsoleIOContext extends IOContext {
             throw new IOException(ex);
         }
         input.shutdown();
+        backgroundWork.shutdown();
     }
 
     private Stream<String> toSplitEntries(String entry) {
@@ -354,7 +351,7 @@ class ConsoleIOContext extends IOContext {
                     doc = repl.analysis.documentation(prefix + text, cursor + prefix.length(), false)
                                        .stream()
                                        .map(Documentation::signature)
-                                       .collect(Collectors.toList());
+                                       .toList();
                 }
                 long smartCount = suggestions.stream().filter(Suggestion::matchesType).count();
                 boolean hasSmart = smartCount > 0 && smartCount <= /*in.getAutoprintThreshold()*/AUTOPRINT_THRESHOLD;
@@ -364,11 +361,49 @@ class ConsoleIOContext extends IOContext {
                                              .distinct()
                                              .count() == 2;
                 boolean tooManyItems = suggestions.size() > /*in.getAutoprintThreshold()*/AUTOPRINT_THRESHOLD;
-                CompletionTask ordinaryCompletion =
-                        new OrdinaryCompletionTask(suggestions,
-                                                   anchor[0],
-                                                   !command && !doc.isEmpty(),
-                                                   hasBoth);
+                CompletionTask ordinaryCompletion;
+                List<? extends CharSequence> ordinaryCompletionToShow;
+
+                if (hasBoth) {
+                    ordinaryCompletionToShow =
+                        suggestions.stream()
+                                   .filter(Suggestion::matchesType)
+                                   .map(Suggestion::continuation)
+                                   .distinct()
+                                   .toList();
+                } else {
+                    ordinaryCompletionToShow =
+                        suggestions.stream()
+                                   .map(Suggestion::continuation)
+                                   .distinct()
+                                   .toList();
+                }
+
+                if (ordinaryCompletionToShow.isEmpty()) {
+                    ordinaryCompletion = new ContinueCompletionTask();
+                } else {
+                    Optional<String> prefixOpt =
+                            suggestions.stream()
+                                       .map(Suggestion::continuation)
+                                       .reduce(ConsoleIOContext::commonPrefix);
+
+                    String prefix =
+                            prefixOpt.orElse("").substring(cursor - anchor[0]);
+
+                    if (!prefix.isEmpty() && !command) {
+                        //the completion will fill in the prefix, which will invalidate
+                        //the documentation, avoid adding documentation tasks into the
+                        //todo list:
+                        doc = List.of();
+                    }
+
+                    ordinaryCompletion =
+                            new OrdinaryCompletionTask(ordinaryCompletionToShow,
+                                                       prefix,
+                                                       !command && !doc.isEmpty(),
+                                                       hasBoth);
+                }
+
                 CompletionTask allCompletion = new AllSuggestionsCompletionTask(suggestions, anchor[0]);
 
                 todo = new ArrayList<>();
@@ -567,17 +602,17 @@ class ConsoleIOContext extends IOContext {
     }
 
     private final class OrdinaryCompletionTask implements CompletionTask {
-        private final List<Suggestion> suggestions;
-        private final int anchor;
+        private final List<? extends CharSequence> toShow;
+        private final String prefix;
         private final boolean cont;
         private final boolean showSmart;
 
-        public OrdinaryCompletionTask(List<Suggestion> suggestions,
-                                      int anchor,
+        public OrdinaryCompletionTask(List<? extends CharSequence> toShow,
+                                      String prefix,
                                       boolean cont,
                                       boolean showSmart) {
-            this.suggestions = suggestions;
-            this.anchor = anchor;
+            this.toShow = toShow;
+            this.prefix = prefix;
             this.cont = cont;
             this.showSmart = showSmart;
         }
@@ -589,34 +624,7 @@ class ConsoleIOContext extends IOContext {
 
         @Override
         public Result perform(String text, int cursor) throws IOException {
-            List<CharSequence> toShow;
-
-            if (showSmart) {
-                toShow =
-                    suggestions.stream()
-                               .filter(Suggestion::matchesType)
-                               .map(Suggestion::continuation)
-                               .distinct()
-                               .collect(Collectors.toList());
-            } else {
-                toShow =
-                    suggestions.stream()
-                               .map(Suggestion::continuation)
-                               .distinct()
-                               .collect(Collectors.toList());
-            }
-
-            if (toShow.isEmpty()) {
-                return Result.CONTINUE;
-            }
-
-            Optional<String> prefix =
-                    suggestions.stream()
-                               .map(Suggestion::continuation)
-                               .reduce(ConsoleIOContext::commonPrefix);
-
-            String prefixStr = prefix.orElse("").substring(cursor - anchor);
-            in.putString(prefixStr);
+            in.putString(prefix);
 
             boolean showItems = toShow.size() > 1 || showSmart;
 
@@ -625,7 +633,7 @@ class ConsoleIOContext extends IOContext {
                 printColumns(toShow);
             }
 
-            if (!prefixStr.isEmpty())
+            if (!prefix.isEmpty())
                 return showItems ? Result.FINISH : Result.SKIP_NOREPAINT;
 
             return cont ? Result.CONTINUE : Result.FINISH;
@@ -658,7 +666,7 @@ class ConsoleIOContext extends IOContext {
                     suggestions.stream()
                                .map(Suggestion::continuation)
                                .distinct()
-                               .collect(Collectors.toList());
+                               .toList();
 
             Optional<String> prefix =
                     candidates.stream()
@@ -792,12 +800,25 @@ class ConsoleIOContext extends IOContext {
             List<String> doc = repl.analysis.documentation(prefix + text, cursor + prefix.length(), true)
                                             .stream()
                                             .map(convertor)
-                                            .collect(Collectors.toList());
+                                            .toList();
             return doPrintFullDocumentation(todo, doc, false);
         }
 
     }
 
+    private static class ContinueCompletionTask implements ConsoleIOContext.CompletionTask {
+
+        @Override
+        public String description() {
+            throw new UnsupportedOperationException("Should not get here.");
+        }
+
+        @Override
+        public CompletionTask.Result perform(String text, int cursor) throws IOException {
+            return CompletionTask.Result.CONTINUE;
+        }
+    }
+
     @Override
     public boolean terminalEditorRunning() {
         Terminal terminal = in.getTerminal();
@@ -815,7 +836,8 @@ class ConsoleIOContext extends IOContext {
     @Override
     public void beforeUserCode() {
         synchronized (this) {
-            inputBytes = null;
+            pendingBytes = null;
+            pendingLine = null;
         }
         input.setState(State.BUFFER);
     }
@@ -946,33 +968,78 @@ class ConsoleIOContext extends IOContext {
         }
     }
 
-    private byte[] inputBytes;
-    private int inputBytesPointer;
+    private String pendingLine;
+    private int pendingLinePointer;
+    private byte[] pendingBytes;
+    private int pendingBytesPointer;
 
     @Override
     public synchronized int readUserInput() throws IOException {
-        while (inputBytes == null || inputBytes.length <= inputBytesPointer) {
-            History prevHistory = in.getHistory();
-            boolean prevDisableCr = Display.DISABLE_CR;
-            Parser prevParser = in.getParser();
-
-            try {
-                in.setParser((line, cursor, context) -> new ArgumentLine(line, cursor));
-                input.setState(State.WAIT);
-                Display.DISABLE_CR = true;
-                in.setHistory(userInputHistory);
-                inputBytes = (in.readLine("") + System.getProperty("line.separator")).getBytes();
-                inputBytesPointer = 0;
-            } catch (UserInterruptException ex) {
-                throw new InterruptedIOException();
-            } finally {
-                in.setParser(prevParser);
-                in.setHistory(prevHistory);
-                input.setState(State.BUFFER);
-                Display.DISABLE_CR = prevDisableCr;
-            }
+        if (pendingBytes == null || pendingBytes.length <= pendingBytesPointer) {
+            char userChar = readUserInputChar();
+            pendingBytes = String.valueOf(userChar).getBytes();
+            pendingBytesPointer = 0;
         }
-        return inputBytes[inputBytesPointer++];
+        return pendingBytes[pendingBytesPointer++];
+    }
+
+    @Override
+    public synchronized char readUserInputChar() throws IOException {
+        while (pendingLine == null || pendingLine.length() <= pendingLinePointer) {
+            pendingLine = doReadUserLine("", null) + System.getProperty("line.separator");
+            pendingLinePointer = 0;
+        }
+        return pendingLine.charAt(pendingLinePointer++);
+    }
+
+    @Override
+    public synchronized String readUserLine(String prompt) throws IOException {
+        //TODO: correct behavior w.r.t. pre-read stuff?
+        if (pendingLine != null && pendingLine.length() > pendingLinePointer) {
+            return pendingLine.substring(pendingLinePointer);
+        }
+        return doReadUserLine(prompt, null);
+    }
+
+    @Override
+    public String readUserLine() throws IOException {
+        return readUserLine("");
+    }
+
+    private synchronized String doReadUserLine(String prompt, Character mask) throws IOException {
+        History prevHistory = in.getHistory();
+        boolean prevDisableCr = Display.DISABLE_CR;
+        Parser prevParser = in.getParser();
+
+        try {
+            in.setParser((line, cursor, context) -> new ArgumentLine(line, cursor));
+            input.setState(State.WAIT);
+            Display.DISABLE_CR = true;
+            in.setHistory(userInputHistory);
+            return in.readLine(prompt.replace("%", "%%"), mask);
+        } catch (UserInterruptException ex) {
+            throw new InterruptedIOException();
+        } finally {
+            in.setParser(prevParser);
+            in.setHistory(prevHistory);
+            input.setState(State.BUFFER);
+            Display.DISABLE_CR = prevDisableCr;
+        }
+    }
+
+    public char[] readPassword(String prompt) throws IOException {
+        //TODO: correct behavior w.r.t. pre-read stuff?
+        return doReadUserLine(prompt, '\0').toCharArray();
+    }
+
+    @Override
+    public Charset charset() {
+        return in.getTerminal().encoding();
+    }
+
+    @Override
+    public Writer userOutput() {
+        return in.getTerminal().writer();
     }
 
     private int countPendingOpenBraces(String code) {
@@ -1252,28 +1319,32 @@ class ConsoleIOContext extends IOContext {
         return in.getHistory();
     }
 
-    private static final class TestTerminal extends LineDisciplineTerminal {
+    private static class ProgrammaticInTerminal extends LineDisciplineTerminal {
 
-        private static final int DEFAULT_HEIGHT = 24;
+        protected static final int DEFAULT_WIDTH = 80;
+        protected static final int DEFAULT_HEIGHT = 24;
 
         private final NonBlockingReader inputReader;
+        private final Size bufferSize;
 
-        public TestTerminal(InputStream input, OutputStream output) throws Exception {
-            super("test", "ansi", output, Charset.forName("UTF-8"));
+        public ProgrammaticInTerminal(InputStream input, OutputStream output,
+                                       boolean interactive, Size size) throws Exception {
+            this(input, output, interactive ? "ansi" : "dumb",
+                 size != null ? size : new Size(DEFAULT_WIDTH, DEFAULT_HEIGHT),
+                 size != null ? size
+                              : interactive ? new Size(DEFAULT_WIDTH, DEFAULT_HEIGHT)
+                                            : new Size(Integer.MAX_VALUE - 1, DEFAULT_HEIGHT));
+        }
+
+        protected ProgrammaticInTerminal(InputStream input, OutputStream output,
+                                         String terminal, Size size, Size bufferSize) throws Exception {
+            super("non-system-in", terminal, output, UTF_8);
             this.inputReader = NonBlocking.nonBlocking(getName(), input, encoding());
             Attributes a = new Attributes(getAttributes());
             a.setLocalFlag(LocalFlag.ECHO, false);
             setAttributes(attributes);
-            int h = DEFAULT_HEIGHT;
-            try {
-                String hp = System.getProperty("test.terminal.height");
-                if (hp != null && !hp.isEmpty()) {
-                    h = Integer.parseInt(hp);
-                }
-            } catch (Throwable ex) {
-                // ignore
-            }
-            setSize(new Size(80, h));
+            setSize(size);
+            this.bufferSize = bufferSize;
         }
 
         @Override
@@ -1288,6 +1359,31 @@ class ConsoleIOContext extends IOContext {
             inputReader.close();
         }
 
+        @Override
+        public Size getBufferSize() {
+            return bufferSize;
+        }
+    }
+
+    private static final class TestTerminal extends ProgrammaticInTerminal {
+        private static Size computeSize() {
+            int h = DEFAULT_HEIGHT;
+            try {
+                String hp = System.getProperty("test.terminal.height");
+                if (hp != null && !hp.isEmpty() && System.getProperty("test.jdk") != null) {
+                    h = Integer.parseInt(hp);
+                }
+            } catch (Throwable ex) {
+                // ignore
+            }
+            return new Size(DEFAULT_WIDTH, h);
+        }
+        public TestTerminal(InputStream input, OutputStream output) throws Exception {
+            this(input, output, computeSize());
+        }
+        private TestTerminal(InputStream input, OutputStream output, Size size) throws Exception {
+            super(input, output, "ansi", size, size);
+        }
     }
 
     private static final class CompletionState {
@@ -1298,4 +1394,149 @@ class ConsoleIOContext extends IOContext {
         public List<CompletionTask> todo = Collections.emptyList();
     }
 
+    private class HighlighterImpl implements Highlighter {
+
+        private final boolean useComplexDeprecationHighlight;
+        private List<UIHighlight> highlights;
+        private String prevBuffer;
+
+        public HighlighterImpl(boolean useComplexDeprecationHighlight) {
+            this.useComplexDeprecationHighlight = useComplexDeprecationHighlight;
+        }
+
+        @Override
+        public AttributedString highlight(LineReader reader, String buffer) {
+            AttributedStringBuilder builder = new AttributedStringBuilder();
+            List<UIHighlight> highlights;
+            synchronized (this) {
+                highlights = this.highlights;
+            }
+            int idx = 0;
+            if (highlights != null) {
+                for (UIHighlight h : highlights) {
+                    if (h.end <= buffer.length() && h.content.equals(buffer.substring(h.start, h.end))) {
+                        builder.append(buffer.substring(idx, h.start));
+                        builder.append(buffer.substring(h.start, h.end), h.style);
+                        idx = h.end;
+                    }
+                }
+            }
+            builder.append(buffer.substring(idx, buffer.length()));
+            synchronized (this) {
+                if (!buffer.equals(prevBuffer)) {
+                    prevBuffer = buffer;
+                    backgroundWork.submit(() -> {
+                        synchronized (HighlighterImpl.this) {
+                            if (!buffer.equals(prevBuffer)) {
+                                return ;
+                            }
+                        }
+                        List<UIHighlight> computedHighlights = new ArrayList<>();
+                        for (Highlight h : repl.analysis.highlights(buffer)) {
+                            computedHighlights.add(new UIHighlight(h.start(), h.end(), buffer.substring(h.start(), h.end()), toAttributedStyle(h.attributes())));
+                        }
+                        synchronized (HighlighterImpl.this) {
+                            if (buffer.equals(prevBuffer)) {
+                                HighlighterImpl.this.highlights = computedHighlights;
+                            }
+                        }
+                        ((JShellLineReader) reader).repaint();
+                    });
+                }
+            }
+            return builder.toAttributedString();
+        }
+
+        private AttributedStyle toAttributedStyle(Set<Attribute> attributes) {
+            AttributedStyle result = AttributedStyle.DEFAULT;
+            if (attributes.contains(Attribute.DECLARATION)) {
+                result = result.bold();
+            }
+            if (attributes.contains(Attribute.DEPRECATED)) {
+                result = useComplexDeprecationHighlight ? result.faint().italic()
+                                                        : result.inverse();
+            }
+            if (attributes.contains(Attribute.KEYWORD)) {
+                result = result.underline();
+            }
+            return result;
+        }
+
+        @Override
+        public void setErrorPattern(Pattern errorPattern) {
+        }
+
+        @Override
+        public void setErrorIndex(int errorIndex) {
+        }
+
+        record UIHighlight(int start, int end, String content, AttributedStyle style) {}
+    }
+
+    private class JShellLineReader extends LineReaderImpl {
+
+        public JShellLineReader(Terminal terminal, String appName, Map<String, Object> variables) {
+            super(terminal, appName, variables);
+            //jline can handle the CONT signal on its own, but (currently) requires sun.misc for it
+            try {
+                Signal.handle(new Signal("CONT"), new Handler() {
+                    @Override public void handle(Signal sig) {
+                        try {
+                            handleSignal(jdk.internal.org.jline.terminal.Terminal.Signal.CONT);
+                        } catch (Exception ex) {
+                            ex.printStackTrace();
+                        }
+                    }
+                });
+            } catch (IllegalArgumentException ignored) {
+                //the CONT signal does not exist on this platform
+            }
+        }
+
+        CompletionState completionState = new CompletionState();
+
+        @Override
+        protected boolean doComplete(CompletionType lst, boolean useMenu, boolean prefix) {
+            return ConsoleIOContext.this.complete(completionState);
+        }
+
+        @Override
+        public Binding readBinding(KeyMap<Binding> keys, KeyMap<Binding> local) {
+            completionState.actionCount++;
+            return super.readBinding(keys, local);
+        }
+
+        @Override
+        protected boolean insertCloseParen() {
+            Object oldIndent = getVariable(INDENTATION);
+            try {
+                setVariable(INDENTATION, 0);
+                return super.insertCloseParen();
+            } finally {
+                setVariable(INDENTATION, oldIndent);
+            }
+        }
+
+        @Override
+        protected boolean insertCloseSquare() {
+            Object oldIndent = getVariable(INDENTATION);
+            try {
+                setVariable(INDENTATION, 0);
+                return super.insertCloseSquare();
+            } finally {
+                setVariable(INDENTATION, oldIndent);
+            }
+        }
+
+        void repaint() {
+            try {
+                lock.lock();
+                if (isReading()) {
+                    redisplay();
+                }
+            } finally {
+                lock.unlock();
+            }
+        }
+    }
 }
