@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2015, 2019, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2015, 2025, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -38,14 +38,7 @@ import java.security.cert.CertificateFactory;
 import java.security.cert.CertificateParsingException;
 import java.security.cert.X509Certificate;
 import java.text.MessageFormat;
-import java.util.ArrayList;
-import java.util.Arrays;
-import java.util.Collection;
-import java.util.Collections;
-import java.util.HashSet;
-import java.util.LinkedList;
-import java.util.List;
-import java.util.Locale;
+import java.util.*;
 import javax.net.ssl.SSLEngine;
 import javax.net.ssl.SSLException;
 import javax.net.ssl.SSLProtocolException;
@@ -137,6 +130,19 @@ final class CertificateMessage {
                     byte[] encodedCert = Record.getBytes24(m);
                     listLen -= (3 + encodedCert.length);
                     encodedCerts.add(encodedCert);
+                    int maxAllowedChainLength = handshakeContext.sslConfig.isClientMode ?
+                            SSLConfiguration.maxInboundServerCertChainLen :
+                            SSLConfiguration.maxInboundClientCertChainLen;
+
+                    if (encodedCerts.size() > maxAllowedChainLength) {
+                        throw new SSLProtocolException(
+                                "The certificate chain length ("
+                                + encodedCerts.size()
+                                + ") exceeds the maximum allowed length ("
+                                + maxAllowedChainLength
+                                + ")");
+                    }
+
                 }
                 this.encodedCertChain = encodedCerts;
             } else {
@@ -185,7 +191,7 @@ final class CertificateMessage {
                 for (byte[] encodedCert : encodedCertChain) {
                     Object obj;
                     try {
-                        obj = (X509Certificate)cf.generateCertificate(
+                        obj = cf.generateCertificate(
                                     new ByteArrayInputStream(encodedCert));
                     } catch (CertificateException ce) {
                         obj = encodedCert;
@@ -201,9 +207,10 @@ final class CertificateMessage {
             }
 
             MessageFormat messageFormat = new MessageFormat(
-                    "\"Certificates\": [\n" +
-                    "{0}\n" +
-                    "]",
+                    """
+                            "Certificates": [
+                            {0}
+                            ]""",
                     Locale.ENGLISH);
             Object[] messageFields = {
                 SSLLogger.toString(x509Certs)
@@ -378,8 +385,8 @@ final class CertificateMessage {
                 if (shc.sslConfig.clientAuthType !=
                         ClientAuthType.CLIENT_AUTH_REQUESTED) {
                     // unexpected or require client authentication
-                    throw shc.conContext.fatal(Alert.BAD_CERTIFICATE,
-                        "Empty server certificate chain");
+                    throw shc.conContext.fatal(Alert.HANDSHAKE_FAILURE,
+                        "Empty client certificate chain");
                 } else {
                     return;
                 }
@@ -396,7 +403,7 @@ final class CertificateMessage {
                 }
             } catch (CertificateException ce) {
                 throw shc.conContext.fatal(Alert.BAD_CERTIFICATE,
-                    "Failed to parse server certificates", ce);
+                    "Failed to parse client certificates", ce);
             }
 
             checkClientCerts(shc, x509Certs);
@@ -564,7 +571,7 @@ final class CertificateMessage {
                     if ((subAltDnsName != null) && !subAltDnsName.isEmpty()) {
                         if (subAltDnsNames == null) {
                             subAltDnsNames =
-                                    new HashSet<>(subjectAltNames.size());
+                                    HashSet.newHashSet(subjectAltNames.size());
                         }
                         subAltDnsNames.add(subAltDnsName);
                     }
@@ -578,7 +585,7 @@ final class CertificateMessage {
                 Collection<String> prevSubAltNames) {
             for (String thisSubAltName : thisSubAltNames) {
                 for (String prevSubAltName : prevSubAltNames) {
-                    // Only allow the exactly match.  No wildcard character
+                    // Only allow exact match.  No wildcard character
                     // checking.
                     if (thisSubAltName.equalsIgnoreCase(prevSubAltName)) {
                         return true;
@@ -604,8 +611,8 @@ final class CertificateMessage {
 
             X509TrustManager tm = chc.sslContext.getX509TrustManager();
 
-            // find out the key exchange algorithm used
-            // use "RSA" for non-ephemeral "RSA_EXPORT"
+            // Find out the key exchange algorithm used.
+            // Use "RSA" for non-ephemeral "RSA_EXPORT".
             String keyExchangeString;
             if (chc.negotiatedCipherSuite.keyExchange ==
                     CipherSuite.KeyExchange.K_RSA_EXPORT ||
@@ -618,8 +625,7 @@ final class CertificateMessage {
 
             try {
                 if (tm instanceof X509ExtendedTrustManager) {
-                    if (chc.conContext.transport instanceof SSLEngine) {
-                        SSLEngine engine = (SSLEngine)chc.conContext.transport;
+                    if (chc.conContext.transport instanceof SSLEngine engine) {
                         ((X509ExtendedTrustManager)tm).checkServerTrusted(
                             certs.clone(),
                             keyExchangeString,
@@ -668,8 +674,7 @@ final class CertificateMessage {
 
             try {
                 if (tm instanceof X509ExtendedTrustManager) {
-                    if (shc.conContext.transport instanceof SSLEngine) {
-                        SSLEngine engine = (SSLEngine)shc.conContext.transport;
+                    if (shc.conContext.transport instanceof SSLEngine engine) {
                         ((X509ExtendedTrustManager)tm).checkClientTrusted(
                             certs.clone(),
                             authType,
@@ -708,9 +713,7 @@ final class CertificateMessage {
             Alert alert = Alert.CERTIFICATE_UNKNOWN;
 
             Throwable baseCause = cexc.getCause();
-            if (baseCause instanceof CertPathValidatorException) {
-                CertPathValidatorException cpve =
-                        (CertPathValidatorException)baseCause;
+            if (baseCause instanceof CertPathValidatorException cpve) {
                 Reason reason = cpve.getReason();
                 if (reason == BasicReason.REVOKED) {
                     alert = chc.staplingActive ?
@@ -758,13 +761,16 @@ final class CertificateMessage {
 
         @Override
         public String toString() {
+            // X.509 certificate
             MessageFormat messageFormat = new MessageFormat(
-                "\n'{'\n" +
-                "{0}\n" +                       // X.509 certificate
-                "  \"extensions\": '{'\n" +
-                "{1}\n" +
-                "  '}'\n" +
-                "'}',", Locale.ENGLISH);
+                    """
+
+                            '{'
+                            {0}
+                              "extensions": '{'
+                            {1}
+                              '}'
+                            '}',""", Locale.ENGLISH);
 
             Object x509Certs;
             try {
@@ -859,6 +865,18 @@ final class CertificateMessage {
                 SSLExtensions extensions =
                         new SSLExtensions(this, m, enabledExtensions);
                 certList.add(new CertificateEntry(encodedCert, extensions));
+                int maxAllowedChainLength = handshakeContext.sslConfig.isClientMode ?
+                        SSLConfiguration.maxInboundServerCertChainLen :
+                        SSLConfiguration.maxInboundClientCertChainLen;
+
+                if (certList.size() > maxAllowedChainLength) {
+                    throw new SSLProtocolException(
+                            "The certificate chain length ("
+                            + certList.size()
+                            + ") exceeds the maximum allowed length ("
+                            + maxAllowedChainLength
+                            + ")");
+                }
             }
 
             this.certEntries = Collections.unmodifiableList(certList);
@@ -902,10 +920,12 @@ final class CertificateMessage {
         @Override
         public String toString() {
             MessageFormat messageFormat = new MessageFormat(
-                "\"Certificate\": '{'\n" +
-                "  \"certificate_request_context\": \"{0}\",\n" +
-                "  \"certificate_list\": [{1}\n]\n" +
-                "'}'",
+                    """
+                            "Certificate": '{'
+                              "certificate_request_context": "{0}",
+                              "certificate_list": [{1}
+                            ]
+                            '}'""",
                 Locale.ENGLISH);
 
             StringBuilder builder = new StringBuilder(512);
@@ -956,12 +976,11 @@ final class CertificateMessage {
                         "No available authentication scheme");
             }
 
-            if (!(pos instanceof X509Possession)) {
+            if (!(pos instanceof X509Possession x509Possession)) {
                 throw shc.conContext.fatal(Alert.HANDSHAKE_FAILURE,
                         "No X.509 certificate for server authentication");
             }
 
-            X509Possession x509Possession = (X509Possession)pos;
             X509Certificate[] localCerts = x509Possession.popCerts;
             if (localCerts == null || localCerts.length == 0) {
                 throw shc.conContext.fatal(Alert.HANDSHAKE_FAILURE,
@@ -982,8 +1001,8 @@ final class CertificateMessage {
             }
 
             // Check the OCSP stapling extensions and attempt
-            // to get responses.  If the resulting stapleParams is non
-            // null, it implies that stapling is enabled on the server side.
+            // to get responses.  If the resulting stapleParams is non-null,
+            // it implies that stapling is enabled on the server side.
             shc.stapleParams = StatusResponseManager.processStapling(shc);
             shc.staplingActive = (shc.stapleParams != null);
 
@@ -1015,7 +1034,7 @@ final class CertificateMessage {
 
         private static SSLPossession choosePossession(
                 HandshakeContext hc,
-                ClientHelloMessage clientHello) throws IOException {
+                ClientHelloMessage clientHello) {
             if (hc.peerRequestedCertSignSchemes == null ||
                     hc.peerRequestedCertSignSchemes.isEmpty()) {
                 if (SSLLogger.isOn && SSLLogger.isOn("ssl,handshake")) {
@@ -1025,58 +1044,28 @@ final class CertificateMessage {
                 return null;
             }
 
-            Collection<String> checkedKeyTypes = new HashSet<>();
-            for (SignatureScheme ss : hc.peerRequestedCertSignSchemes) {
-                if (checkedKeyTypes.contains(ss.keyAlgorithm)) {
-                    if (SSLLogger.isOn && SSLLogger.isOn("ssl,handshake")) {
-                        SSLLogger.warning(
-                            "Unsupported authentication scheme: " + ss.name);
-                    }
-                    continue;
+            String[] supportedKeyTypes = hc.peerRequestedCertSignSchemes
+                    .stream()
+                    .map(ss -> ss.keyAlgorithm)
+                    .distinct()
+                    .filter(ka -> SignatureScheme.getPreferableAlgorithm(   // Don't select a signature scheme unless
+                            hc.algorithmConstraints,                        //  we will be able to produce
+                            hc.peerRequestedSignatureSchemes,               //  a CertificateVerify message later
+                            ka, hc.negotiatedProtocol) != null
+                            || SSLLogger.logWarning("ssl,handshake",
+                                    "Unable to produce CertificateVerify for key algorithm: " + ka))
+                    .filter(ka -> X509Authentication.valueOfKeyAlgorithm(ka) != null
+                            || SSLLogger.logWarning("ssl,handshake", "Unsupported key algorithm: " + ka))
+                    .toArray(String[]::new);
+
+            SSLPossession pos = X509Authentication
+                    .createPossession(hc, supportedKeyTypes);
+            if (pos == null) {
+                if (SSLLogger.isOn && SSLLogger.isOn("ssl,handshake")) {
+                    SSLLogger.warning("No available authentication scheme");
                 }
-
-                // Don't select a signature scheme unless we will be able to
-                // produce a CertificateVerify message later
-                if (SignatureScheme.getPreferableAlgorithm(
-                        hc.algorithmConstraints,
-                        hc.peerRequestedSignatureSchemes,
-                        ss, hc.negotiatedProtocol) == null) {
-
-                    if (SSLLogger.isOn && SSLLogger.isOn("ssl,handshake")) {
-                        SSLLogger.warning(
-                            "Unable to produce CertificateVerify for " +
-                            "signature scheme: " + ss.name);
-                    }
-                    checkedKeyTypes.add(ss.keyAlgorithm);
-                    continue;
-                }
-
-                SSLAuthentication ka = X509Authentication.valueOf(ss);
-                if (ka == null) {
-                    if (SSLLogger.isOn && SSLLogger.isOn("ssl,handshake")) {
-                        SSLLogger.warning(
-                            "Unsupported authentication scheme: " + ss.name);
-                    }
-                    checkedKeyTypes.add(ss.keyAlgorithm);
-                    continue;
-                }
-
-                SSLPossession pos = ka.createPossession(hc);
-                if (pos == null) {
-                    if (SSLLogger.isOn && SSLLogger.isOn("ssl,handshake")) {
-                        SSLLogger.warning(
-                            "Unavailable authentication scheme: " + ss.name);
-                    }
-                    continue;
-                }
-
-                return pos;
             }
-
-            if (SSLLogger.isOn && SSLLogger.isOn("ssl,handshake")) {
-                SSLLogger.warning("No available authentication scheme");
-            }
-            return null;
+            return pos;
         }
 
         private byte[] onProduceCertificate(ClientHandshakeContext chc,
@@ -1091,14 +1080,13 @@ final class CertificateMessage {
                 localCerts = new X509Certificate[0];
             } else {
                 chc.handshakePossessions.add(pos);
-                if (!(pos instanceof X509Possession)) {
+                if (!(pos instanceof X509Possession x509Possession)) {
                     if (SSLLogger.isOn && SSLLogger.isOn("ssl,handshake")) {
                         SSLLogger.fine(
                             "No X.509 certificate for client authentication");
                     }
                     localCerts = new X509Certificate[0];
                 } else {
-                    X509Possession x509Possession = (X509Possession)pos;
                     localCerts = x509Possession.popCerts;
                     chc.handshakeSession.setLocalPrivateKey(
                             x509Possession.popPrivateKey);
@@ -1149,6 +1137,15 @@ final class CertificateMessage {
 
             // clean up this consumer
             hc.handshakeConsumers.remove(SSLHandshake.CERTIFICATE.id);
+
+            // Ensure that the Certificate message has not been sent w/o
+            // an EncryptedExtensions preceding
+            if (hc.handshakeConsumers.containsKey(
+                    SSLHandshake.ENCRYPTED_EXTENSIONS.id)) {
+                throw hc.conContext.fatal(Alert.UNEXPECTED_MESSAGE,
+                                           "Unexpected Certificate handshake message");
+            }
+
             T13CertificateMessage cm = new T13CertificateMessage(hc, message);
             if (hc.sslConfig.isClientMode) {
                 if (SSLLogger.isOn && SSLLogger.isOn("ssl,handshake")) {
@@ -1174,7 +1171,7 @@ final class CertificateMessage {
                 shc.handshakeConsumers.remove(
                         SSLHandshake.CERTIFICATE_VERIFY.id);
                 if (shc.sslConfig.clientAuthType == CLIENT_AUTH_REQUIRED) {
-                    throw shc.conContext.fatal(Alert.BAD_CERTIFICATE,
+                    throw shc.conContext.fatal(Alert.CERTIFICATE_REQUIRED,
                         "Empty client certificate chain");
                 } else {
                     // optional client authentication
@@ -1198,14 +1195,14 @@ final class CertificateMessage {
                 T13CertificateMessage certificateMessage )throws IOException {
             if (certificateMessage.certEntries == null ||
                     certificateMessage.certEntries.isEmpty()) {
-                throw chc.conContext.fatal(Alert.BAD_CERTIFICATE,
+                throw chc.conContext.fatal(Alert.DECODE_ERROR,
                     "Empty server certificate chain");
             }
 
             // Each CertificateEntry will have its own set of extensions
             // which must be consumed.
             SSLExtension[] enabledExtensions =
-                chc.sslConfig.getEnabledExtensions(SSLHandshake.CERTIFICATE);
+                    chc.sslConfig.getEnabledExtensions(SSLHandshake.CERTIFICATE);
             for (CertificateEntry certEnt : certificateMessage.certEntries) {
                 certEnt.extensions.consumeOnLoad(chc, enabledExtensions);
             }
@@ -1236,7 +1233,7 @@ final class CertificateMessage {
                 }
             } catch (CertificateException ce) {
                 throw shc.conContext.fatal(Alert.BAD_CERTIFICATE,
-                    "Failed to parse server certificates", ce);
+                    "Failed to parse client certificates", ce);
             }
 
             // find out the types of client authentication used
@@ -1257,8 +1254,7 @@ final class CertificateMessage {
             try {
                 X509TrustManager tm = shc.sslContext.getX509TrustManager();
                 if (tm instanceof X509ExtendedTrustManager) {
-                    if (shc.conContext.transport instanceof SSLEngine) {
-                        SSLEngine engine = (SSLEngine)shc.conContext.transport;
+                    if (shc.conContext.transport instanceof SSLEngine engine) {
                         ((X509ExtendedTrustManager)tm).checkClientTrusted(
                             certs.clone(),
                             authType,
@@ -1313,8 +1309,7 @@ final class CertificateMessage {
             try {
                 X509TrustManager tm = chc.sslContext.getX509TrustManager();
                 if (tm instanceof X509ExtendedTrustManager) {
-                    if (chc.conContext.transport instanceof SSLEngine) {
-                        SSLEngine engine = (SSLEngine)chc.conContext.transport;
+                    if (chc.conContext.transport instanceof SSLEngine engine) {
                         ((X509ExtendedTrustManager)tm).checkServerTrusted(
                             certs.clone(),
                             authType,
@@ -1359,9 +1354,7 @@ final class CertificateMessage {
             Alert alert = Alert.CERTIFICATE_UNKNOWN;
 
             Throwable baseCause = cexc.getCause();
-            if (baseCause instanceof CertPathValidatorException) {
-                CertPathValidatorException cpve =
-                        (CertPathValidatorException)baseCause;
+            if (baseCause instanceof CertPathValidatorException cpve) {
                 Reason reason = cpve.getReason();
                 if (reason == BasicReason.REVOKED) {
                     alert = chc.staplingActive ?
