@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2025, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -71,42 +67,47 @@ public class FormatData_ar_DZ extends ListResourceBundle {
     @Override
     protected final Object[][] getContents() {
         final String[] metaValue_MonthNames = new String[] {
-               "\u062c\u0627\u0646\u0641\u064a",
-               "\u0641\u064a\u0641\u0631\u064a",
-               "\u0645\u0627\u0631\u0633",
-               "\u0623\u0641\u0631\u064a\u0644",
-               "\u0645\u0627\u064a",
-               "\u062c\u0648\u0627\u0646",
-               "\u062c\u0648\u064a\u0644\u064a\u0629",
-               "\u0623\u0648\u062a",
-               "\u0633\u0628\u062a\u0645\u0628\u0631",
-               "\u0623\u0643\u062a\u0648\u0628\u0631",
-               "\u0646\u0648\u0641\u0645\u0628\u0631",
-               "\u062f\u064a\u0633\u0645\u0628\u0631",
-               "",
-            };
+            "\u062c\u0627\u0646\u0641\u064a",
+            "\u0641\u064a\u0641\u0631\u064a",
+            "\u0645\u0627\u0631\u0633",
+            "\u0623\u0641\u0631\u064a\u0644",
+            "\u0645\u0627\u064a",
+            "\u062c\u0648\u0627\u0646",
+            "\u062c\u0648\u064a\u0644\u064a\u0629",
+            "\u0623\u0648\u062a",
+            "\u0633\u0628\u062a\u0645\u0628\u0631",
+            "\u0623\u0643\u062a\u0648\u0628\u0631",
+            "\u0646\u0648\u0641\u0645\u0628\u0631",
+            "\u062f\u064a\u0633\u0645\u0628\u0631",
+            "",
+        };
         final String[] metaValue_MonthNarrows = new String[] {
-               "\u062c",
-               "\u0641",
-               "\u0645",
-               "\u0623",
-               "\u0645",
-               "\u062c",
-               "\u062c",
-               "\u0623",
-               "\u0633",
-               "\u0623",
-               "\u0646",
-               "\u062f",
-               "",
-            };
+            "\u062c",
+            "\u0641",
+            "\u0645",
+            "\u0623",
+            "\u0645",
+            "\u062c",
+            "\u062c",
+            "\u0623",
+            "\u0633",
+            "\u0623",
+            "\u0646",
+            "\u062f",
+            "",
+        };
         final Object[][] data = new Object[][] {
             { "MonthNames", metaValue_MonthNames },
-            { "japanese.MonthNames", metaValue_MonthNames },
-            { "roc.MonthAbbreviations", metaValue_MonthNames },
-            { "buddhist.MonthAbbreviations", metaValue_MonthNames },
+            { "standalone.MonthNames", metaValue_MonthNames },
             { "MonthAbbreviations", metaValue_MonthNames },
+            { "standalone.MonthAbbreviations", metaValue_MonthNames },
+            { "MonthNarrows", metaValue_MonthNarrows },
+            { "standalone.MonthNarrows", metaValue_MonthNarrows },
             { "buddhist.MonthNames", metaValue_MonthNames },
+            { "japanese.MonthNames", metaValue_MonthNames },
+            { "japanese.MonthAbbreviations", metaValue_MonthNames },
+            { "roc.MonthNames", metaValue_MonthNames },
+            { "roc.MonthAbbreviations", metaValue_MonthNames },
             { "latn.NumberElements",
                 new String[] {
                     ",",
@@ -120,26 +121,18 @@ public class FormatData_ar_DZ extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "\u0644\u064a\u0633\u00a0\u0631\u0642\u0645\u064b\u0627",
+                    "",
+                    "",
                 }
             },
-            { "roc.MonthNarrows", metaValue_MonthNarrows },
-            { "MonthNarrows", metaValue_MonthNarrows },
-            { "japanese.MonthAbbreviations", metaValue_MonthNames },
-            { "roc.MonthNames", metaValue_MonthNames },
-            { "standalone.MonthNames", metaValue_MonthNames },
-            { "standalone.MonthAbbreviations", metaValue_MonthNames },
-            { "DefaultNumberingSystem", "latn" },
             { "latn.NumberPatterns",
                 new String[] {
                     "#,##0.###",
-                    "\u00a4\u00a0#,##0.00",
+                    "\u200f#,##0.00\u00a0\u00a4;\u200f-#,##0.00\u00a0\u00a4",
                     "#,##0%",
-                    "\u00a4#,##0.00;(\u00a4#,##0.00)",
+                    "\u061c#,##0.00\u00a4;(\u061c#,##0.00\u00a4)",
                 }
             },
-            { "standalone.MonthNarrows", metaValue_MonthNarrows },
-            { "buddhist.MonthNarrows", metaValue_MonthNarrows },
-            { "japanese.MonthNarrows", metaValue_MonthNarrows },
         };
         return data;
     }
