@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2024, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2025, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -182,7 +182,6 @@ public class FormatData_fo extends ListResourceBundle {
         final String metaValue_generic_DateFormatItem_MEd = "E dd.MM";
         final String metaValue_generic_DateFormatItem_MMMEd = "E d. MMM";
         final String metaValue_generic_DateFormatItem_d = "d.";
-        final String metaValue_generic_DateFormatItem_h = "h\u202fa";
         final String metaValue_generic_DateFormatItem_GyMd = "dd.MM.y G";
         final String metaValue_generic_DateFormatItem_yMd = "dd.MM.y";
         final String metaValue_generic_DateFormatItem_MMMd = "d. MMM";
@@ -217,6 +216,7 @@ public class FormatData_fo extends ListResourceBundle {
             "d. MMM y GGGG",
             "dd.MM.y G",
         };
+        final String metaValue_buddhist_DateFormatItem_h = "h\u202fa";
         final String metaValue_calendarname_gregorian = "gregorianskur kalendari";
         final String[] metaValue_ListPatterns_or = new String[] {
             "",
@@ -271,7 +271,6 @@ public class FormatData_fo extends ListResourceBundle {
             { "generic.DateFormatItem.MMMEd", metaValue_generic_DateFormatItem_MMMEd },
             { "generic.DateFormatItem.yyyyQQQ", "QQQ '\u00ed' y G" },
             { "generic.DateFormatItem.d", metaValue_generic_DateFormatItem_d },
-            { "generic.DateFormatItem.h", metaValue_generic_DateFormatItem_h },
             { "generic.DateFormatItem.GyMd", metaValue_generic_DateFormatItem_GyMd },
             { "generic.DateFormatItem.GyMMMEd", metaValue_generic_DateFormatItem_yyyyMMMEd },
             { "generic.DateFormatItem.yyyyM", "MM.y GGGGG" },
@@ -377,7 +376,6 @@ public class FormatData_fo extends ListResourceBundle {
             { "DateFormatItem.MEd", metaValue_generic_DateFormatItem_MEd },
             { "DateFormatItem.MMMEd", metaValue_generic_DateFormatItem_MMMEd },
             { "DateFormatItem.d", metaValue_generic_DateFormatItem_d },
-            { "DateFormatItem.h", metaValue_generic_DateFormatItem_h },
             { "DateFormatItem.GyMd", metaValue_generic_DateFormatItem_GyMd },
             { "DateFormatItem.GyMMMEd", metaValue_generic_DateFormatItem_yyyyMMMEd },
             { "DateFormatItem.yMd", metaValue_generic_DateFormatItem_yMd },
@@ -417,7 +415,7 @@ public class FormatData_fo extends ListResourceBundle {
             { "buddhist.DateFormatItem.MEd", metaValue_generic_DateFormatItem_MEd },
             { "buddhist.DateFormatItem.MMMEd", metaValue_generic_DateFormatItem_MMMEd },
             { "buddhist.DateFormatItem.d", metaValue_generic_DateFormatItem_d },
-            { "buddhist.DateFormatItem.h", metaValue_generic_DateFormatItem_h },
+            { "buddhist.DateFormatItem.h", metaValue_buddhist_DateFormatItem_h },
             { "buddhist.DateFormatItem.GyMd", metaValue_generic_DateFormatItem_GyMd },
             { "buddhist.DateFormatItem.GyMMMEd", metaValue_generic_DateFormatItem_yyyyMMMEd },
             { "buddhist.DateFormatItem.yMd", metaValue_generic_DateFormatItem_yMd },
@@ -457,7 +455,7 @@ public class FormatData_fo extends ListResourceBundle {
             { "japanese.DateFormatItem.MEd", metaValue_generic_DateFormatItem_MEd },
             { "japanese.DateFormatItem.MMMEd", metaValue_generic_DateFormatItem_MMMEd },
             { "japanese.DateFormatItem.d", metaValue_generic_DateFormatItem_d },
-            { "japanese.DateFormatItem.h", metaValue_generic_DateFormatItem_h },
+            { "japanese.DateFormatItem.h", metaValue_buddhist_DateFormatItem_h },
             { "japanese.DateFormatItem.GyMd", metaValue_generic_DateFormatItem_GyMd },
             { "japanese.DateFormatItem.GyMMMEd", metaValue_generic_DateFormatItem_yyyyMMMEd },
             { "japanese.DateFormatItem.yMd", metaValue_generic_DateFormatItem_yMd },
@@ -498,7 +496,7 @@ public class FormatData_fo extends ListResourceBundle {
             { "roc.DateFormatItem.MEd", metaValue_generic_DateFormatItem_MEd },
             { "roc.DateFormatItem.MMMEd", metaValue_generic_DateFormatItem_MMMEd },
             { "roc.DateFormatItem.d", metaValue_generic_DateFormatItem_d },
-            { "roc.DateFormatItem.h", metaValue_generic_DateFormatItem_h },
+            { "roc.DateFormatItem.h", metaValue_buddhist_DateFormatItem_h },
             { "roc.DateFormatItem.GyMd", metaValue_generic_DateFormatItem_GyMd },
             { "roc.DateFormatItem.GyMMMEd", metaValue_generic_DateFormatItem_yyyyMMMEd },
             { "roc.DateFormatItem.yMd", metaValue_generic_DateFormatItem_yMd },
@@ -536,7 +534,7 @@ public class FormatData_fo extends ListResourceBundle {
             { "islamic.DateFormatItem.MEd", metaValue_generic_DateFormatItem_MEd },
             { "islamic.DateFormatItem.MMMEd", metaValue_generic_DateFormatItem_MMMEd },
             { "islamic.DateFormatItem.d", metaValue_generic_DateFormatItem_d },
-            { "islamic.DateFormatItem.h", metaValue_generic_DateFormatItem_h },
+            { "islamic.DateFormatItem.h", metaValue_buddhist_DateFormatItem_h },
             { "islamic.DateFormatItem.GyMd", metaValue_generic_DateFormatItem_GyMd },
             { "islamic.DateFormatItem.GyMMMEd", metaValue_generic_DateFormatItem_yyyyMMMEd },
             { "islamic.DateFormatItem.yMd", metaValue_generic_DateFormatItem_yMd },
@@ -567,7 +565,7 @@ public class FormatData_fo extends ListResourceBundle {
             { "islamic-civil.DateFormatItem.MEd", metaValue_generic_DateFormatItem_MEd },
             { "islamic-civil.DateFormatItem.MMMEd", metaValue_generic_DateFormatItem_MMMEd },
             { "islamic-civil.DateFormatItem.d", metaValue_generic_DateFormatItem_d },
-            { "islamic-civil.DateFormatItem.h", metaValue_generic_DateFormatItem_h },
+            { "islamic-civil.DateFormatItem.h", metaValue_buddhist_DateFormatItem_h },
             { "islamic-civil.DateFormatItem.GyMd", metaValue_generic_DateFormatItem_GyMd },
             { "islamic-civil.DateFormatItem.GyMMMEd", metaValue_generic_DateFormatItem_yyyyMMMEd },
             { "islamic-civil.DateFormatItem.yMd", metaValue_generic_DateFormatItem_yMd },
@@ -598,7 +596,7 @@ public class FormatData_fo extends ListResourceBundle {
             { "islamic-umalqura.DateFormatItem.MEd", metaValue_generic_DateFormatItem_MEd },
             { "islamic-umalqura.DateFormatItem.MMMEd", metaValue_generic_DateFormatItem_MMMEd },
             { "islamic-umalqura.DateFormatItem.d", metaValue_generic_DateFormatItem_d },
-            { "islamic-umalqura.DateFormatItem.h", metaValue_generic_DateFormatItem_h },
+            { "islamic-umalqura.DateFormatItem.h", metaValue_buddhist_DateFormatItem_h },
             { "islamic-umalqura.DateFormatItem.GyMd", metaValue_generic_DateFormatItem_GyMd },
             { "islamic-umalqura.DateFormatItem.GyMMMEd", metaValue_generic_DateFormatItem_yyyyMMMEd },
             { "islamic-umalqura.DateFormatItem.yMd", metaValue_generic_DateFormatItem_yMd },
@@ -608,9 +606,12 @@ public class FormatData_fo extends ListResourceBundle {
             { "islamic-umalqura.DateFormatItem.MMMMW", metaValue_generic_DateFormatItem_MMMMW },
             { "islamic-umalqura.DateFormatItem.yQQQQ", metaValue_generic_DateFormatItem_yQQQQ },
             { "islamic-umalqura.DateFormatItem.GyMMM", metaValue_generic_DateFormatItem_yyyyMMM },
+            { "calendarname.islamic-civil", "islamiskur kalendari (talvuskapa\u00f0ur, f\u00f3lkaligt t\u00ed\u00f0arskei\u00f0)" },
+            { "calendarname.islamic", "islamiskur kalendari" },
             { "calendarname.buddhist", "buddistiskur kalendari" },
             { "calendarname.japanese", "japanskur kalendari" },
             { "calendarname.roc", "minguo kalendari" },
+            { "calendarname.islamic-umalqura", "islamiskur kalendari (Umm al-Qura)" },
             { "calendarname.gregorian", metaValue_calendarname_gregorian },
             { "calendarname.gregory", metaValue_calendarname_gregorian },
             { "latn.NumberElements",
