@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2024, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2025, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -66,21 +66,13 @@ import sun.util.resources.TimeZoneNamesBundle;
 public class TimeZoneNames_en_CA extends TimeZoneNamesBundle {
     @Override
     protected final Object[][] getContents() {
-        final String[] Apia = new String[] {
-               "Apia Standard Time",
+        final String[] Gulf = new String[] {
+               "Gulf Standard Time",
+               "Gulf Time",
+               "",
                "",
-               "Apia Daylight Saving Time",
                "",
-               "Apia Time",
                "",
-            };
-        final String[] Cuba = new String[] {
-               "Cuba Standard Time",
-               "CST",
-               "Cuba Daylight Saving Time",
-               "CDT",
-               "Cuba Time",
-               "CT",
             };
         final String[] Iran = new String[] {
                "Iran Standard Time",
@@ -98,14 +90,6 @@ public class TimeZoneNames_en_CA extends TimeZoneNamesBundle {
                "Peru Time",
                "PET",
             };
-        final String[] China = new String[] {
-               "China Standard Time",
-               "CST",
-               "China Daylight Saving Time",
-               "CDT",
-               "China Time",
-               "CT",
-            };
         final String[] Cocos = new String[] {
                "Cocos Islands Time",
                "CCT",
@@ -118,25 +102,9 @@ public class TimeZoneNames_en_CA extends TimeZoneNamesBundle {
                "India Standard Time",
                "IST",
                "",
+               "IST",
                "",
-               "",
-               "",
-            };
-        final String[] Japan = new String[] {
-               "Japan Standard Time",
-               "JST",
-               "Japan Daylight Saving Time",
-               "JDT",
-               "Japan Time",
-               "JT",
-            };
-        final String[] Korea = new String[] {
-               "Korean Standard Time",
-               "KST",
-               "Korean Daylight Saving Time",
-               "KST",
-               "Korean Time",
-               "KST",
+               "IST",
             };
         final String[] Nepal = new String[] {
                "Nepal Time",
@@ -149,7 +117,7 @@ public class TimeZoneNames_en_CA extends TimeZoneNamesBundle {
         final String[] Samoa = new String[] {
                "Samoa Standard Time",
                "SST",
-               "Samoa Daylight Saving Time",
+               "Samoan Time",
                "SST",
                "Samoa Time",
                "SST",
@@ -194,22 +162,6 @@ public class TimeZoneNames_en_CA extends TimeZoneNamesBundle {
                "",
                "",
             };
-        final String[] Israel = new String[] {
-               "Israel Standard Time",
-               "IST",
-               "Israel Daylight Saving Time",
-               "IDT",
-               "Israel Time",
-               "IT",
-            };
-        final String[] Taipei = new String[] {
-               "Taipei Standard Time",
-               "CST",
-               "Taipei Daylight Saving Time",
-               "CDT",
-               "Taipei Time",
-               "CT",
-            };
         final String[] Wallis = new String[] {
                "Wallis and Futuna Time",
                "",
@@ -218,18 +170,10 @@ public class TimeZoneNames_en_CA extends TimeZoneNamesBundle {
                "",
                "",
             };
-        final String[] Arabian = new String[] {
-               "Arabian Standard Time",
-               "",
-               "Arabian Daylight Saving Time",
-               "",
-               "Arabian Time",
-               "",
-            };
         final String[] Chatham = new String[] {
                "Chatham Standard Time",
                "CHAST",
-               "Chatham Daylight Saving Time",
+               "Chatham Daylight Time",
                "CHADT",
                "Chatham Time",
                "",
@@ -242,14 +186,6 @@ public class TimeZoneNames_en_CA extends TimeZoneNamesBundle {
                "",
                "",
             };
-        final String[] Norfolk = new String[] {
-               "Norfolk Island Standard Time",
-               "",
-               "Norfolk Island Daylight Saving Time",
-               "",
-               "Norfolk Island Time",
-               "",
-            };
         final String[] Noronha = new String[] {
                "Fernando de Noronha Standard Time",
                "",
@@ -266,14 +202,6 @@ public class TimeZoneNames_en_CA extends TimeZoneNamesBundle {
                "Uruguay Time",
                "",
             };
-        final String[] Atlantic = new String[] {
-               "Atlantic Standard Time",
-               "AST",
-               "Atlantic Daylight Saving Time",
-               "ADT",
-               "Atlantic Time",
-               "AT",
-            };
         final String[] Brasilia = new String[] {
                "Brasilia Standard Time",
                "",
@@ -362,14 +290,6 @@ public class TimeZoneNames_en_CA extends TimeZoneNamesBundle {
                "",
                "",
             };
-        final String[] Lord_Howe = new String[] {
-               "Lord Howe Standard Time",
-               "",
-               "Lord Howe Daylight Saving Time",
-               "",
-               "Lord Howe Time",
-               "",
-            };
         final String[] Venezuela = new String[] {
                "Venezuela Time",
                "VET",
@@ -410,30 +330,14 @@ public class TimeZoneNames_en_CA extends TimeZoneNamesBundle {
                "",
                "",
             };
-        final String[] New_Zealand = new String[] {
-               "New Zealand Standard Time",
-               "NZST",
-               "New Zealand Daylight Saving Time",
-               "NZDT",
-               "New Zealand Time",
-               "NZT",
-            };
         final String[] Newfoundland = new String[] {
                "Newfoundland Standard Time",
                "NST",
-               "Newfoundland Daylight Saving Time",
+               "Newfoundland Daylight Time",
                "NDT",
                "Newfoundland Time",
                "NT",
             };
-        final String[] Mexico_Pacific = new String[] {
-               "Mexican Pacific Standard Time",
-               "MST",
-               "Mexican Pacific Daylight Saving Time",
-               "MDT",
-               "Mexican Pacific Time",
-               "MT",
-            };
         final String[] America_Central = new String[] {
                "Central Standard Time",
                "CST",
@@ -450,14 +354,6 @@ public class TimeZoneNames_en_CA extends TimeZoneNamesBundle {
                "Eastern Time",
                "ET",
             };
-        final String[] America_Pacific = new String[] {
-               "Pacific Standard Time",
-               "PST",
-               "Pacific Daylight Saving Time",
-               "PDT",
-               "Pacific Time",
-               "PT",
-            };
         final String[] French_Southern = new String[] {
                "French Southern and Antarctic Time",
                "",
@@ -466,14 +362,6 @@ public class TimeZoneNames_en_CA extends TimeZoneNamesBundle {
                "",
                "",
             };
-        final String[] Hawaii_Aleutian = new String[] {
-               "Hawaii-Aleutian Standard Time",
-               "HAST",
-               "Hawaii-Aleutian Daylight Saving Time",
-               "HADT",
-               "Hawaii-Aleutian Time",
-               "HAT",
-            };
         final String[] Pierre_Miquelon = new String[] {
                "Saint-Pierre-et-Miquelon Standard Time",
                "PMST",
@@ -482,34 +370,10 @@ public class TimeZoneNames_en_CA extends TimeZoneNamesBundle {
                "Saint-Pierre-et-Miquelon Time",
                "PMT",
             };
-        final String[] America_Mountain = new String[] {
-               "Mountain Standard Time",
-               "MST",
-               "Mountain Daylight Saving Time",
-               "MDT",
-               "Mountain Time",
-               "MT",
-            };
-        final String[] Mexico_Northwest = new String[] {
-               "Northwest Mexico Standard Time",
-               "",
-               "Northwest Mexico Daylight Saving Time",
-               "",
-               "Northwest Mexico Time",
-               "",
-            };
-        final String[] Australia_Central = new String[] {
-               "Australian Central Standard Time",
-               "ACST",
-               "Australian Central Daylight Saving Time",
-               "ACDT",
-               "Central Australia Time",
-               "ACT",
-            };
         final String[] Australia_Eastern = new String[] {
                "Australian Eastern Standard Time",
                "AEST",
-               "Australian Eastern Daylight Saving Time",
+               "Australian Eastern Daylight Time",
                "AEDT",
                "Eastern Australia Time",
                "AET",
@@ -517,18 +381,10 @@ public class TimeZoneNames_en_CA extends TimeZoneNamesBundle {
         final String[] Australia_Western = new String[] {
                "Australian Western Standard Time",
                "AWST",
-               "Australian Western Daylight Saving Time",
+               "Australian Western Daylight Time",
                "AWDT",
                "Western Australia Time",
-               "",
-            };
-        final String[] Greenland_Eastern = new String[] {
-               "East Greenland Standard Time",
-               "",
-               "East Greenland Summer Time",
-               "",
-               "East Greenland Time",
-               "EGT",
+               "AWT",
             };
         final String[] Indonesia_Central = new String[] {
                "Central Indonesia Time",
@@ -557,95 +413,80 @@ public class TimeZoneNames_en_CA extends TimeZoneNamesBundle {
         final String[] Australia_CentralWestern = new String[] {
                "Australian Central Western Standard Time",
                "ACWST",
-               "Australian Central Western Daylight Saving Time",
+               "Australian Central Western Daylight Time",
                "ACWDT",
                "Australian Central Western Time",
                "ACWT",
             };
         final Object[][] data = new Object[][] {
-            { "America/Los_Angeles", America_Pacific },
-            { "America/Denver", America_Mountain },
-            { "America/Phoenix", America_Mountain },
             { "America/Chicago", America_Central },
             { "America/New_York", America_Eastern },
             { "America/Indianapolis", America_Eastern },
-            { "Pacific/Honolulu", Hawaii_Aleutian },
             { "America/Anchorage", Alaska },
-            { "America/Halifax", Atlantic },
             { "America/Sitka", Alaska },
             { "America/St_Johns", Newfoundland },
-            { "Asia/Jerusalem", Israel },
-            { "Asia/Tokyo", Japan },
-            { "Asia/Shanghai", China },
             { "UTC", EMPTY_ZONE },
-            { "ACT", Australia_Central },
             { "AET", Australia_Eastern },
+            { "AGT", Argentina },
             { "AST", Alaska },
             { "BET", Brasilia },
             { "BST", Bangladesh },
             { "CNT", Newfoundland },
             { "CST", America_Central },
-            { "CTT", China },
-            { "JST", Japan },
-            { "MIT", Apia },
-            { "NST", New_Zealand },
+            { "EST", America_Eastern },
+            { "IET", America_Eastern },
+            { "IST", India },
             { "PLT", Pakistan },
-            { "PNT", America_Mountain },
-            { "PRT", Atlantic },
-            { "PST", America_Pacific },
+            { "VST", Indochina },
+            { "Iran", Iran },
             { "CST6CDT", America_Central },
             { "EST5EDT", America_Eastern },
-            { "MST7MDT", America_Mountain },
-            { "PST8PDT", America_Pacific },
-            { "Asia/Aden", Arabian },
+            { "Jamaica", America_Eastern },
+            { "NZ-CHAT", Chatham },
+            { "US/Samoa", Samoa },
             { "Asia/Dili", East_Timor },
+            { "US/Alaska", Alaska },
+            { "Asia/Dacca", Bangladesh },
             { "Asia/Dhaka", Bangladesh },
+            { "Asia/Dubai", Gulf },
             { "Asia/Kabul", Afghanistan },
-            { "Asia/Macau", China },
-            { "Asia/Qatar", Arabian },
-            { "Asia/Seoul", Korea },
+            { "US/Central", America_Central },
+            { "US/Eastern", America_Eastern },
             { "Asia/Brunei", Brunei },
-            { "Asia/Harbin", China },
-            { "Asia/Kuwait", Arabian },
-            { "Asia/Riyadh", Arabian },
+            { "Asia/Muscat", Gulf },
             { "Asia/Saigon", Indochina },
-            { "Asia/Taipei", Taipei },
             { "Asia/Tehran", Iran },
-            { "America/Adak", Hawaii_Aleutian },
+            { "Asia/Thimbu", Bhutan },
+            { "Asia/Yangon", Cocos },
+            { "Brazil/East", Brasilia },
+            { "US/Michigan", America_Eastern },
             { "America/Lima", Peru },
             { "America/Nome", Alaska },
-            { "Asia/Baghdad", Arabian },
-            { "Asia/Bahrain", Arabian },
             { "Asia/Bangkok", Indochina },
             { "Asia/Colombo", India },
             { "Asia/Jakarta", Indonesia_Western },
             { "Asia/Karachi", Pakistan },
-            { "Asia/Kuching", Malaysia },
+            { "Asia/Kolkata", India },
+            { "Asia/Kuching", Brunei },
             { "Asia/Thimphu", Bhutan },
             { "Indian/Cocos", Cocos },
-            { "Pacific/Apia", Apia },
-            { "SystemV/AST4", Atlantic },
             { "SystemV/CST6", America_Central },
             { "SystemV/EST5", America_Eastern },
-            { "SystemV/MST7", America_Mountain },
-            { "America/Aruba", Atlantic },
             { "America/Bahia", Brasilia },
             { "America/Belem", Brasilia },
-            { "America/Boise", America_Mountain },
             { "America/Jujuy", Argentina },
-            { "America/Thule", Atlantic },
             { "Asia/Calcutta", India },
             { "Asia/Jayapura", Indonesia_Eastern },
             { "Asia/Katmandu", Nepal },
             { "Asia/Makassar", Indonesia_Central },
-            { "SystemV/HST10", Hawaii_Aleutian },
+            { "Australia/ACT", Australia_Eastern },
+            { "Australia/NSW", Australia_Eastern },
+            { "Pacific/Samoa", Samoa },
             { "America/Belize", America_Central },
             { "America/Bogota", Colombia },
             { "America/Cancun", America_Eastern },
             { "America/Cayman", America_Eastern },
             { "America/Guyana", Guyana },
-            { "America/Havana", Cuba },
-            { "America/Inuvik", America_Mountain },
             { "America/Juneau", Alaska },
             { "America/Maceio", Brasilia },
             { "America/Merida", America_Central },
@@ -653,136 +494,107 @@ public class TimeZoneNames_en_CA extends TimeZoneNamesBundle {
             { "America/Panama", America_Eastern },
             { "America/Recife", Brasilia },
             { "America/Regina", America_Central },
-            { "Asia/Chongqing", China },
+            { "Asia/Kathmandu", Nepal },
             { "Asia/Pontianak", Indonesia_Western },
-            { "Asia/Pyongyang", Korea },
+            { "Asia/Singapore", Malaysia },
             { "Asia/Vientiane", Indochina },
+            { "Australia/West", Australia_Western },
+            { "Canada/Central", America_Central },
+            { "Canada/Eastern", America_Eastern },
+            { "Indian/Reunion", Gulf },
+            { "Mexico/General", America_Central },
             { "Pacific/Easter", Easter },
             { "Pacific/Midway", Samoa },
+            { "Pacific/Tarawa", Wallis },
             { "Pacific/Wallis", Wallis },
-            { "America/Antigua", Atlantic },
             { "America/Caracas", Venezuela },
             { "America/Cordoba", Argentina },
-            { "America/Creston", America_Mountain },
-            { "America/Curacao", Atlantic },
             { "America/Detroit", America_Eastern },
-            { "America/Grenada", Atlantic },
             { "America/Iqaluit", America_Eastern },
             { "America/Jamaica", America_Eastern },
+            { "America/Knox_IN", America_Central },
             { "America/Managua", America_Central },
-            { "America/Marigot", Atlantic },
             { "America/Mendoza", Argentina },
-            { "America/Moncton", Atlantic },
             { "America/Nipigon", America_Eastern },
             { "America/Noronha", Noronha },
             { "America/Ojinaga", America_Central },
-            { "America/Tijuana", America_Pacific },
             { "America/Toronto", America_Eastern },
-            { "America/Tortola", Atlantic },
             { "America/Yakutat", Alaska },
             { "Asia/Phnom_Penh", Indochina },
             { "Australia/Eucla", Australia_CentralWestern },
             { "Australia/Perth", Australia_Western },
-            { "Indian/Maldives", Maldives },
+            { "Indian/Maldives", French_Southern },
             { "Pacific/Chatham", Chatham },
-            { "Pacific/Norfolk", Norfolk },
-            { "SystemV/AST4ADT", Atlantic },
             { "SystemV/CST6CDT", America_Central },
             { "SystemV/EST5EDT", America_Eastern },
-            { "SystemV/MST7MDT", America_Mountain },
-            { "SystemV/PST8PDT", America_Pacific },
             { "SystemV/YST9YDT", Alaska },
-            { "America/Anguilla", Atlantic },
             { "America/Asuncion", Paraguay },
-            { "America/Barbados", Atlantic },
-            { "America/Dominica", Atlantic },
-            { "America/Edmonton", America_Mountain },
-            { "America/Mazatlan", Mexico_Pacific },
+            { "America/Atikokan", America_Eastern },
             { "America/Miquelon", Pierre_Miquelon },
             { "America/Montreal", America_Eastern },
             { "America/Resolute", America_Central },
             { "America/Santarem", Brasilia },
-            { "America/Shiprock", America_Mountain },
-            { "America/St_Kitts", Atlantic },
-            { "America/St_Lucia", Atlantic },
             { "America/Winnipeg", America_Central },
-            { "Atlantic/Bermuda", Atlantic },
+            { "Antarctica/Casey", Australia_Western },
+            { "Asia/Ho_Chi_Minh", Indochina },
             { "Atlantic/Stanley", Falkland },
             { "Australia/Currie", Australia_Eastern },
-            { "Australia/Darwin", Australia_Central },
             { "Australia/Hobart", Australia_Eastern },
             { "Australia/Sydney", Australia_Eastern },
+            { "Brazil/DeNoronha", Noronha },
             { "Indian/Christmas", Christmas },
             { "Indian/Kerguelen", French_Southern },
-            { "Pacific/Auckland", New_Zealand },
-            { "Pacific/Johnston", Hawaii_Aleutian },
             { "America/Araguaina", Brasilia },
             { "America/Catamarca", Argentina },
             { "America/Chihuahua", America_Central },
             { "America/Fortaleza", Brasilia },
-            { "America/Glace_Bay", Atlantic },
-            { "America/Goose_Bay", Atlantic },
             { "America/Guatemala", America_Central },
             { "America/Guayaquil", Ecuador },
             { "America/Matamoros", America_Central },
             { "America/Menominee", America_Central },
             { "America/Monterrey", America_Central },
             { "America/Sao_Paulo", Brasilia },
-            { "America/St_Thomas", Atlantic },
-            { "America/Vancouver", America_Pacific },
             { "Asia/Kuala_Lumpur", Malaysia },
             { "Pacific/Galapagos", Galapagos },
             { "Pacific/Pago_Pago", Samoa },
+            { "US/Indiana-Starke", America_Central },
             { "America/Costa_Rica", America_Central },
             { "America/Grand_Turk", America_Eastern },
-            { "America/Guadeloupe", Atlantic },
-            { "America/Hermosillo", Mexico_Pacific },
-            { "America/Kralendijk", Atlantic },
             { "America/Louisville", America_Eastern },
-            { "America/Martinique", Atlantic },
             { "America/Metlakatla", Alaska },
             { "America/Montevideo", Uruguay },
-            { "America/Montserrat", Atlantic },
-            { "America/St_Vincent", Atlantic },
-            { "Antarctica/McMurdo", New_Zealand },
-            { "Australia/Adelaide", Australia_Central },
+            { "Asia/Ujung_Pandang", Indonesia_Central },
             { "Australia/Brisbane", Australia_Eastern },
+            { "Australia/Canberra", Australia_Eastern },
             { "Australia/Lindeman", Australia_Eastern },
+            { "Australia/Tasmania", Australia_Eastern },
+            { "Australia/Victoria", Australia_Eastern },
+            { "Chile/EasterIsland", Easter },
             { "America/El_Salvador", America_Central },
-            { "America/Fort_Nelson", America_Mountain },
             { "America/Mexico_City", America_Central },
             { "America/Pangnirtung", America_Eastern },
-            { "America/Puerto_Rico", Atlantic },
             { "America/Rainy_River", America_Central },
             { "America/Tegucigalpa", America_Central },
             { "America/Thunder_Bay", America_Eastern },
-            { "America/Yellowknife", America_Mountain },
-            { "Australia/Lord_Howe", Lord_Howe },
             { "Australia/Melbourne", Australia_Eastern },
-            { "America/Blanc-Sablon", Atlantic },
+            { "Canada/Newfoundland", Newfoundland },
+            { "Canada/Saskatchewan", America_Central },
             { "America/Buenos_Aires", Argentina },
-            { "America/Dawson_Creek", America_Mountain },
             { "America/Indiana/Knox", America_Central },
             { "America/Rankin_Inlet", America_Central },
-            { "America/Santa_Isabel", Mexico_Northwest },
-            { "America/Scoresbysund", Greenland_Eastern },
             { "Antarctica/Macquarie", Australia_Eastern },
-            { "America/Cambridge_Bay", America_Mountain },
-            { "America/Ciudad_Juarez", America_Mountain },
+            { "Australia/Queensland", Australia_Eastern },
             { "America/Coral_Harbour", America_Eastern },
             { "America/Indiana/Vevay", America_Eastern },
-            { "America/Lower_Princes", Atlantic },
-            { "America/Port_of_Spain", Atlantic },
-            { "America/Santo_Domingo", Atlantic },
-            { "America/St_Barthelemy", Atlantic },
             { "America/Swift_Current", America_Central },
-            { "Antarctica/South_Pole", New_Zealand },
-            { "Australia/Broken_Hill", Australia_Central },
             { "America/Bahia_Banderas", America_Central },
             { "America/Port-au-Prince", America_Eastern },
+            { "America/Argentina/Jujuy", Argentina },
             { "America/Argentina/Salta", Argentina },
             { "America/Indiana/Marengo", America_Eastern },
             { "America/Indiana/Winamac", America_Eastern },
+            { "America/Argentina/Cordoba", Argentina },
+            { "America/Argentina/Mendoza", Argentina },
             { "America/Argentina/Tucuman", Argentina },
             { "America/Argentina/Ushuaia", Argentina },
             { "America/Indiana/Tell_City", America_Central },
@@ -791,11 +603,14 @@ public class TimeZoneNames_en_CA extends TimeZoneNamesBundle {
             { "America/Argentina/San_Juan", Argentina },
             { "America/Argentina/San_Luis", Argentina },
             { "America/Indiana/Petersburg", America_Eastern },
-            { "timezone.excity.Asia/Aqtau", "Aktau" },
+            { "America/Argentina/Catamarca", Argentina },
+            { "America/Kentucky/Louisville", America_Eastern },
             { "America/Kentucky/Monticello", America_Eastern },
             { "America/North_Dakota/Beulah", America_Central },
             { "America/North_Dakota/Center", America_Central },
+            { "America/Indiana/Indianapolis", America_Eastern },
             { "timezone.excity.Asia/Rangoon", "Rangoon" },
+            { "America/Argentina/Buenos_Aires", Argentina },
             { "America/Argentina/Rio_Gallegos", Argentina },
             { "America/North_Dakota/New_Salem", America_Central },
             { "timezone.excity.America/St_Johns", "Saint John\u2019s" },
