@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2022, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2025, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -84,17 +84,23 @@ public class TimeZoneNames_es_AR extends TimeZoneNamesBundle {
             };
         final Object[][] data = new Object[][] {
             { "UTC", EMPTY_ZONE },
+            { "AGT", Argentina },
             { "America/Jujuy", Argentina },
             { "America/Cordoba", Argentina },
             { "America/Mendoza", Argentina },
             { "America/Catamarca", Argentina },
             { "America/Buenos_Aires", Argentina },
+            { "America/Argentina/Jujuy", Argentina },
             { "America/Argentina/Salta", Argentina },
+            { "America/Argentina/Cordoba", Argentina },
+            { "America/Argentina/Mendoza", Argentina },
             { "America/Argentina/Tucuman", Argentina },
             { "America/Argentina/Ushuaia", Argentina },
             { "America/Argentina/La_Rioja", Argentina },
             { "America/Argentina/San_Juan", Argentina },
             { "America/Argentina/San_Luis", Argentina },
+            { "America/Argentina/Catamarca", Argentina },
+            { "America/Argentina/Buenos_Aires", Argentina },
             { "America/Argentina/Rio_Gallegos", Argentina },
         };
         return data;
