@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2022, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2025, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -76,11 +76,11 @@ public class TimeZoneNames_gsw extends TimeZoneNamesBundle {
             };
         final String[] Alaska = new String[] {
                "Alaska-Schtandardziit",
-               "",
+               "AKST",
                "Alaska-Summerziit",
-               "",
+               "AKDT",
                "Alaska-Ziit",
-               "",
+               "AKT",
             };
         final String[] Amazon = new String[] {
                "Amazonas-Schtandardziit",
@@ -92,11 +92,11 @@ public class TimeZoneNames_gsw extends TimeZoneNamesBundle {
             };
         final String[] Moscow = new String[] {
                "Moskauer Schtandardziit",
-               "",
+               "MSK",
                "Moskauer Summerziit",
-               "",
+               "MSK",
                "Moskauer Ziit",
-               "",
+               "MSK",
             };
         final String[] EMPTY_ZONE = new String[] {
                "",
@@ -116,27 +116,27 @@ public class TimeZoneNames_gsw extends TimeZoneNamesBundle {
             };
         final String[] Africa_Central = new String[] {
                "Zentralafrikanischi Ziit",
+               "CAT",
                "",
+               "CAT",
                "",
-               "",
-               "",
-               "",
+               "CAT",
             };
         final String[] Africa_Eastern = new String[] {
                "Oschtafrikanischi Ziit",
+               "EAT",
                "",
+               "EAT",
                "",
-               "",
-               "",
-               "",
+               "EAT",
             };
         final String[] Africa_Western = new String[] {
                "Weschtafrikanischi Schtandardziit",
-               "",
+               "WAT",
                "Weschtafrikanischi Summerziit",
-               "",
+               "WAT",
                "Weschtafrikanischi Ziit",
-               "",
+               "WAT",
             };
         final String[] Europe_Central = new String[] {
                "Mitteleurop\u00e4ischi Schtandardziit",
@@ -164,19 +164,19 @@ public class TimeZoneNames_gsw extends TimeZoneNamesBundle {
             };
         final String[] Africa_Southern = new String[] {
                "S\u00fc\u00fcdafrikanischi ziit",
+               "SAST",
                "",
+               "SAST",
                "",
-               "",
-               "",
-               "",
+               "SAST",
             };
         final String[] America_Central = new String[] {
                "Amerika-Zentraal Schtandardziit",
-               "",
+               "CST",
                "Amerika-Zentraal Summerziit",
-               "",
+               "CDT",
                "Amerika-Zentraal Ziit",
-               "",
+               "CT",
             };
         final Object[][] data = new Object[][] {
             { "America/Chicago", America_Central },
@@ -188,17 +188,30 @@ public class TimeZoneNames_gsw extends TimeZoneNamesBundle {
             { "ART", Europe_Eastern },
             { "AST", Alaska },
             { "CAT", Africa_Central },
+            { "CET", Europe_Central },
             { "CST", America_Central },
             { "EAT", Africa_Eastern },
             { "ECT", Europe_Central },
+            { "EET", Europe_Eastern },
+            { "MET", Europe_Central },
+            { "WET", Europe_Western },
+            { "W-SU", Moscow },
+            { "Egypt", Europe_Eastern },
+            { "Libya", Europe_Eastern },
+            { "Poland", Europe_Central },
             { "CST6CDT", America_Central },
+            { "Portugal", Europe_Western },
             { "Asia/Gaza", Europe_Eastern },
-            { "Asia/Amman", Europe_Eastern },
+            { "US/Alaska", Alaska },
             { "Asia/Kabul", Afghanistan },
+            { "US/Central", America_Central },
             { "Africa/Juba", Africa_Central },
             { "Asia/Beirut", Europe_Eastern },
             { "Asia/Hebron", Europe_Eastern },
+            { "Brazil/Acre", Acre },
+            { "Brazil/West", Amazon },
             { "Europe/Kiev", Europe_Eastern },
+            { "Europe/Kyiv", Europe_Eastern },
             { "Europe/Oslo", Europe_Central },
             { "Europe/Riga", Europe_Eastern },
             { "Europe/Rome", Europe_Central },
@@ -213,6 +226,7 @@ public class TimeZoneNames_gsw extends TimeZoneNamesBundle {
             { "Europe/Sofia", Europe_Eastern },
             { "Europe/Vaduz", Europe_Central },
             { "SystemV/CST6", America_Central },
+            { "Africa/Asmara", Africa_Eastern },
             { "Africa/Asmera", Africa_Eastern },
             { "Africa/Bangui", Africa_Western },
             { "Africa/Douala", Africa_Western },
@@ -224,7 +238,6 @@ public class TimeZoneNames_gsw extends TimeZoneNamesBundle {
             { "Africa/Maputo", Africa_Central },
             { "Africa/Maseru", Africa_Southern },
             { "Africa/Niamey", Africa_Western },
-            { "Asia/Damascus", Europe_Eastern },
             { "Europe/Athens", Europe_Eastern },
             { "Europe/Berlin", Europe_Central },
             { "Europe/Lisbon", Europe_Western },
@@ -250,11 +263,15 @@ public class TimeZoneNames_gsw extends TimeZoneNamesBundle {
             { "America/Manaus", Amazon },
             { "America/Merida", America_Central },
             { "America/Regina", America_Central },
+            { "Atlantic/Faroe", Europe_Western },
+            { "Canada/Central", America_Central },
             { "Europe/Andorra", Europe_Central },
+            { "Europe/Nicosia", Europe_Eastern },
             { "Europe/Tallinn", Europe_Eastern },
             { "Europe/Vatican", Europe_Central },
             { "Europe/Vilnius", Europe_Eastern },
             { "Indian/Mayotte", Africa_Eastern },
+            { "Mexico/General", America_Central },
             { "Africa/Blantyre", Africa_Central },
             { "Africa/Djibouti", Africa_Eastern },
             { "Africa/Gaborone", Africa_Central },
@@ -262,7 +279,9 @@ public class TimeZoneNames_gsw extends TimeZoneNamesBundle {
             { "Africa/Kinshasa", Africa_Western },
             { "Africa/Ndjamena", Africa_Western },
             { "Africa/Windhoek", Africa_Central },
+            { "America/Knox_IN", America_Central },
             { "America/Managua", America_Central },
+            { "America/Ojinaga", America_Central },
             { "America/Yakutat", Alaska },
             { "Atlantic/Canary", Europe_Western },
             { "Atlantic/Faeroe", Europe_Western },
@@ -273,6 +292,7 @@ public class TimeZoneNames_gsw extends TimeZoneNamesBundle {
             { "Europe/Chisinau", Europe_Eastern },
             { "Europe/Helsinki", Europe_Eastern },
             { "Europe/Sarajevo", Europe_Central },
+            { "Europe/Tiraspol", Europe_Eastern },
             { "Europe/Uzhgorod", Europe_Eastern },
             { "SystemV/CST6CDT", America_Central },
             { "SystemV/YST9YDT", Alaska },
@@ -292,6 +312,7 @@ public class TimeZoneNames_gsw extends TimeZoneNamesBundle {
             { "Africa/Lubumbashi", Africa_Central },
             { "Africa/Porto-Novo", Africa_Western },
             { "America/Boa_Vista", Amazon },
+            { "America/Chihuahua", America_Central },
             { "America/Guatemala", America_Central },
             { "America/Matamoros", America_Central },
             { "America/Menominee", America_Central },
@@ -302,10 +323,12 @@ public class TimeZoneNames_gsw extends TimeZoneNamesBundle {
             { "Europe/San_Marino", Europe_Central },
             { "Europe/Simferopol", Moscow },
             { "Europe/Zaporozhye", Europe_Eastern },
+            { "US/Indiana-Starke", America_Central },
             { "Africa/Addis_Ababa", Africa_Eastern },
             { "Africa/Brazzaville", Africa_Western },
             { "America/Costa_Rica", America_Central },
             { "America/Metlakatla", Alaska },
+            { "America/Porto_Acre", Acre },
             { "America/Rio_Branco", Acre },
             { "Atlantic/Jan_Mayen", Europe_Central },
             { "Europe/Kaliningrad", Europe_Eastern },
@@ -316,6 +339,7 @@ public class TimeZoneNames_gsw extends TimeZoneNamesBundle {
             { "America/Rainy_River", America_Central },
             { "America/Tegucigalpa", America_Central },
             { "Arctic/Longyearbyen", Europe_Central },
+            { "Canada/Saskatchewan", America_Central },
             { "Indian/Antananarivo", Africa_Eastern },
             { "Africa/Dar_es_Salaam", Africa_Eastern },
             { "America/Campo_Grande", Amazon },
@@ -366,23 +390,18 @@ public class TimeZoneNames_gsw extends TimeZoneNamesBundle {
             { "timezone.excity.Asia/Pyongyang", "Pj\u00f6ngjang" },
             { "timezone.excity.Asia/Singapore", "Singapur" },
             { "timezone.excity.Europe/Vilnius", "Wilna" },
-            { "timezone.excity.Indian/Reunion", "R\u00e9union" },
             { "timezone.excity.Pacific/Easter", "Oschterinsle" },
             { "timezone.excity.Africa/Djibouti", "Dschibuti" },
             { "timezone.excity.Africa/El_Aaiun", "El Aai\u00fan" },
             { "timezone.excity.Africa/Khartoum", "Khartum" },
-            { "timezone.excity.Africa/Sao_Tome", "S\u00e3o Tom\u00e9" },
-            { "timezone.excity.America/Curacao", "Cura\u00e7ao" },
             { "timezone.excity.America/Jamaica", "Jamaika" },
             { "timezone.excity.Atlantic/Azores", "Azore" },
             { "timezone.excity.Atlantic/Canary", "Kanare" },
             { "timezone.excity.Atlantic/Faeroe", "F\u00e4r\u00f6er" },
             { "timezone.excity.Europe/Brussels", "Br\u00fcssel" },
             { "timezone.excity.Europe/Chisinau", "Kischinau" },
-            { "timezone.excity.Europe/Uzhgorod", "Uschgorod" },
             { "timezone.excity.Indian/Maldives", "Maledive" },
             { "timezone.excity.Africa/Mogadishu", "Mogadischu" },
-            { "timezone.excity.America/Asuncion", "Asunci\u00f3n" },
             { "timezone.excity.Asia/Krasnoyarsk", "Krasnojarsk" },
             { "timezone.excity.Asia/Novosibirsk", "Nowosibirsk" },
             { "timezone.excity.Asia/Ulaanbaatar", "Ulan-Baator" },
@@ -393,7 +412,6 @@ public class TimeZoneNames_gsw extends TimeZoneNamesBundle {
             { "timezone.excity.Antarctica/Vostok", "Woschtok" },
             { "timezone.excity.Europe/Copenhagen", "Kopehage" },
             { "timezone.excity.Europe/Luxembourg", "Luxemburg" },
-            { "timezone.excity.Europe/Zaporozhye", "Saporischja" },
             { "timezone.excity.Africa/Addis_Ababa", "Addis Abeba" },
             { "timezone.excity.Africa/Ouagadougou", "Wagadugu" },
             { "timezone.excity.Asia/Yekaterinburg", "Jekaterinburg" },
