@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2024, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2025, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -196,11 +196,11 @@ public class TimeZoneNames_uz_Cyrl extends TimeZoneNamesBundle {
             };
         final String[] India = new String[] {
                "\u04b2\u0438\u043d\u0434\u0438\u0441\u0442\u043e\u043d \u0432\u0430\u049b\u0442\u0438",
+               "IST",
                "",
+               "IST",
                "",
-               "",
-               "",
-               "",
+               "IST",
             };
         final String[] Japan = new String[] {
                "\u042f\u043f\u043e\u043d\u0438\u044f \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0442 \u0432\u0430\u049b\u0442\u0438",
@@ -268,11 +268,11 @@ public class TimeZoneNames_uz_Cyrl extends TimeZoneNamesBundle {
             };
         final String[] Alaska = new String[] {
                "\u0410\u043b\u044f\u0441\u043a\u0430 \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0442 \u0432\u0430\u049b\u0442\u0438",
-               "",
+               "AKST",
                "\u0410\u043b\u044f\u0441\u043a\u0430 \u043a\u0443\u043d\u0434\u0443\u0437\u0433\u0438 \u0432\u0430\u049b\u0442\u0438",
-               "",
+               "AKDT",
                "\u0410\u043b\u044f\u0441\u043a\u0430 \u0432\u0430\u049b\u0442\u0438",
-               "",
+               "AKT",
             };
         final String[] Amazon = new String[] {
                "\u0410\u043c\u0430\u0437\u043e\u043d\u043a\u0430 \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0442 \u0432\u0430\u049b\u0442\u0438",
@@ -284,11 +284,11 @@ public class TimeZoneNames_uz_Cyrl extends TimeZoneNamesBundle {
             };
         final String[] Azores = new String[] {
                "\u0410\u0437\u043e\u0440 \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0442 \u0432\u0430\u049b\u0442\u0438",
-               "HMT",
+               "",
                "\u0410\u0437\u043e\u0440 \u0451\u0437\u0433\u0438 \u0432\u0430\u049b\u0442\u0438",
-               "HMT",
+               "",
                "\u0410\u0437\u043e\u0440 \u0432\u0430\u049b\u0442\u0438",
-               "HMT",
+               "",
             };
         final String[] Bhutan = new String[] {
                "\u0411\u0443\u0442\u0430\u043d \u0432\u0430\u049b\u0442\u0438",
@@ -558,9 +558,9 @@ public class TimeZoneNames_uz_Cyrl extends TimeZoneNamesBundle {
                "\u0410\u0442\u043b\u0430\u043d\u0442\u0438\u043a\u0430 \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0442 \u0432\u0430\u049b\u0442\u0438",
                "AST",
                "\u0410\u0442\u043b\u0430\u043d\u0442\u0438\u043a\u0430 \u043a\u0443\u043d\u0434\u0443\u0437\u0433\u0438 \u0432\u0430\u049b\u0442\u0438",
-               "ADT",
+               "AST",
                "\u0410\u0442\u043b\u0430\u043d\u0442\u0438\u043a\u0430 \u0432\u0430\u049b\u0442\u0438",
-               "AT",
+               "AST",
             };
         final String[] Brasilia = new String[] {
                "\u0411\u0440\u0430\u0437\u0438\u043b\u0438\u044f \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0442 \u0432\u0430\u049b\u0442\u0438",
@@ -932,11 +932,11 @@ public class TimeZoneNames_uz_Cyrl extends TimeZoneNamesBundle {
             };
         final String[] Africa_Central = new String[] {
                "\u041c\u0430\u0440\u043a\u0430\u0437\u0438\u0439 \u0410\u0444\u0440\u0438\u043a\u0430 \u0432\u0430\u049b\u0442\u0438",
-               "SAST",
+               "CAT",
                "",
-               "SAST",
+               "CAT",
                "",
-               "SAST",
+               "CAT",
             };
         final String[] Africa_Eastern = new String[] {
                "\u0428\u0430\u0440\u049b\u0438\u0439 \u0410\u0444\u0440\u0438\u043a\u0430 \u0432\u0430\u049b\u0442\u0438",
@@ -980,11 +980,11 @@ public class TimeZoneNames_uz_Cyrl extends TimeZoneNamesBundle {
             };
         final String[] Europe_Western = new String[] {
                "\u0492\u0430\u0440\u0431\u0438\u0439 \u0415\u0432\u0440\u043e\u043f\u0430 \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0442 \u0432\u0430\u049b\u0442\u0438",
-               "FMT",
+               "WET",
                "\u0492\u0430\u0440\u0431\u0438\u0439 \u0415\u0432\u0440\u043e\u043f\u0430 \u0451\u0437\u0433\u0438 \u0432\u0430\u049b\u0442\u0438",
-               "FMT",
+               "WEST",
                "\u0492\u0430\u0440\u0431\u0438\u0439 \u0415\u0432\u0440\u043e\u043f\u0430 \u0432\u0430\u049b\u0442\u0438",
-               "FMT",
+               "WET",
             };
         final String[] Africa_Southern = new String[] {
                "\u0416\u0430\u043d\u0443\u0431\u0438\u0439 \u0410\u0444\u0440\u0438\u043a\u0430 \u0432\u0430\u049b\u0442\u0438",
@@ -1062,9 +1062,9 @@ public class TimeZoneNames_uz_Cyrl extends TimeZoneNamesBundle {
                "\u0428\u0438\u043c\u043e\u043b\u0438\u0439 \u0410\u043c\u0435\u0440\u0438\u043a\u0430 \u0442\u043e\u0493 \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0442 \u0432\u0430\u049b\u0442\u0438",
                "MST",
                "\u0428\u0438\u043c\u043e\u043b\u0438\u0439 \u0410\u043c\u0435\u0440\u0438\u043a\u0430 \u0442\u043e\u0493 \u043a\u0443\u043d\u0434\u0443\u0437\u0433\u0438 \u0432\u0430\u049b\u0442\u0438",
-               "MDT",
+               "MST",
                "\u0428\u0438\u043c\u043e\u043b\u0438\u0439 \u0410\u043c\u0435\u0440\u0438\u043a\u0430 \u0442\u043e\u0493 \u0432\u0430\u049b\u0442\u0438",
-               "MT",
+               "MST",
             };
         final String[] Marshall_Islands = new String[] {
                "\u041c\u0430\u0440\u0448\u0430\u043b\u043b \u043e\u0440\u043e\u043b\u043b\u0430\u0440\u0438 \u0432\u0430\u049b\u0442\u0438",
@@ -1100,27 +1100,11 @@ public class TimeZoneNames_uz_Cyrl extends TimeZoneNamesBundle {
             };
         final String[] Australia_Western = new String[] {
                "\u0492\u0430\u0440\u0431\u0438\u0439 \u0410\u0432\u0441\u0442\u0440\u0430\u043b\u0438\u044f \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0442 \u0432\u0430\u049b\u0442\u0438",
-               "",
+               "AWST",
                "\u0492\u0430\u0440\u0431\u0438\u0439 \u0410\u0432\u0441\u0442\u0440\u0430\u043b\u0438\u044f \u043a\u0443\u043d\u0434\u0443\u0437\u0433\u0438 \u0432\u0430\u049b\u0442\u0438",
-               "",
+               "AWDT",
                "\u0492\u0430\u0440\u0431\u0438\u0439 \u0410\u0432\u0441\u0442\u0440\u0430\u043b\u0438\u044f \u0432\u0430\u049b\u0442\u0438",
-               "",
-            };
-        final String[] Greenland_Eastern = new String[] {
-               "\u0428\u0430\u0440\u049b\u0438\u0439 \u0413\u0440\u0435\u043d\u043b\u0430\u043d\u0434\u0438\u044f \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0442 \u0432\u0430\u049b\u0442\u0438",
-               "",
-               "\u0428\u0430\u0440\u049b\u0438\u0439 \u0413\u0440\u0435\u043d\u043b\u0430\u043d\u0434\u0438\u044f \u0451\u0437\u0433\u0438 \u0432\u0430\u049b\u0442\u0438",
-               "",
-               "\u0428\u0430\u0440\u049b\u0438\u0439 \u0413\u0440\u0435\u043d\u043b\u0430\u043d\u0434\u0438\u044f \u0432\u0430\u049b\u0442\u0438",
-               "",
-            };
-        final String[] Greenland_Western = new String[] {
-               "\u0492\u0430\u0440\u0431\u0438\u0439 \u0413\u0440\u0435\u043d\u043b\u0430\u043d\u0434\u0438\u044f \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0442 \u0432\u0430\u049b\u0442\u0438",
-               "",
-               "\u0492\u0430\u0440\u0431\u0438\u0439 \u0413\u0440\u0435\u043d\u043b\u0430\u043d\u0434\u0438\u044f \u0451\u0437\u0433\u0438 \u0432\u0430\u049b\u0442\u0438",
-               "",
-               "\u0492\u0430\u0440\u0431\u0438\u0439 \u0413\u0440\u0435\u043d\u043b\u0430\u043d\u0434\u0438\u044f \u0432\u0430\u049b\u0442\u0438",
-               "",
+               "AWT",
             };
         final String[] Indonesia_Central = new String[] {
                "\u041c\u0430\u0440\u043a\u0430\u0437\u0438\u0439 \u0418\u043d\u0434\u043e\u043d\u0435\u0437\u0438\u044f \u0432\u0430\u049b\u0442\u0438",
@@ -1146,22 +1130,6 @@ public class TimeZoneNames_uz_Cyrl extends TimeZoneNamesBundle {
                "",
                "WIB",
             };
-        final String[] Kazakhstan_Eastern = new String[] {
-               "\u0428\u0430\u0440\u049b\u0438\u0439 \u049a\u043e\u0437\u043e\u0493\u0438\u0441\u0442\u043e\u043d \u0432\u0430\u049b\u0442\u0438",
-               "",
-               "",
-               "",
-               "",
-               "",
-            };
-        final String[] Kazakhstan_Western = new String[] {
-               "\u0492\u0430\u0440\u0431\u0438\u0439 \u049a\u043e\u0437\u043e\u0493\u0438\u0441\u0442\u043e\u043d \u0432\u0430\u049b\u0442\u0438",
-               "",
-               "",
-               "",
-               "",
-               "",
-            };
         final String[] Australia_CentralWestern = new String[] {
                "\u041c\u0430\u0440\u043a\u0430\u0437\u0438\u0439 \u0410\u0432\u0441\u0442\u0440\u0430\u043b\u0438\u044f \u0492\u0430\u0440\u0431\u0438\u0439 \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0442 \u0432\u0430\u049b\u0442\u0438",
                "",
@@ -1189,51 +1157,120 @@ public class TimeZoneNames_uz_Cyrl extends TimeZoneNamesBundle {
             { "Europe/Bucharest", Europe_Eastern },
             { "Asia/Shanghai", China },
             { "UTC", EMPTY_ZONE },
+            { "GB",
+                new String[] {
+                    "\u0413\u0440\u0438\u043d\u0432\u0438\u0447 \u0432\u0430\u049b\u0442\u0438",
+                    "GMT",
+                    "\u0411\u0440\u0438\u0442\u0430\u043d\u0438\u044f \u0451\u0437\u0433\u0438 \u0432\u0430\u049b\u0442\u0438",
+                    "BST",
+                    "",
+                    "GMT",
+                }
+            },
+            { "NZ", New_Zealand },
             { "ACT", Australia_Central },
             { "AET", Australia_Eastern },
+            { "AGT", Argentina },
             { "ART", Europe_Eastern },
             { "AST", Alaska },
             { "BET", Brasilia },
             { "BST", Bangladesh },
             { "CAT", Africa_Central },
+            { "CET", Europe_Central },
             { "CNT", Newfoundland },
             { "CST", America_Central },
             { "CTT", China },
             { "EAT", Africa_Eastern },
             { "ECT", Europe_Central },
+            { "EET", Europe_Eastern },
+            { "EST", America_Eastern },
+            { "HST", Hawaii_Aleutian },
+            { "IET", America_Eastern },
+            { "IST", India },
             { "JST", Japan },
+            { "MET", Europe_Central },
+            { "MST", America_Mountain },
             { "NET", Armenia },
             { "NST", New_Zealand },
             { "PLT", Pakistan },
             { "PNT", America_Mountain },
+            { "PRC", China },
             { "PRT", Atlantic },
             { "PST", America_Pacific },
+            { "ROK", Korea },
             { "SST", Solomon },
+            { "VST", Indochina },
+            { "WET", Europe_Western },
+            { "Cuba", Cuba },
+            { "Eire",
+                new String[] {
+                    "\u0413\u0440\u0438\u043d\u0432\u0438\u0447 \u0432\u0430\u049b\u0442\u0438",
+                    "GMT",
+                    "\u0418\u0440\u043b\u0430\u043d\u0434\u0438\u044f \u0451\u0437\u0433\u0438 \u0432\u0430\u049b\u0442\u0438",
+                    "IST",
+                    "",
+                    "GMT",
+                }
+            },
+            { "GMT0", GMT },
+            { "Iran", Iran },
+            { "W-SU", Moscow },
+            { "Egypt", Europe_Eastern },
+            { "Japan", Japan },
+            { "Libya", Europe_Eastern },
+            { "Israel", Israel },
+            { "Navajo", America_Mountain },
+            { "Poland", Europe_Central },
             { "CST6CDT", America_Central },
             { "EST5EDT", America_Eastern },
             { "Etc/GMT", GMT },
+            { "GB-Eire",
+                new String[] {
+                    "\u0413\u0440\u0438\u043d\u0432\u0438\u0447 \u0432\u0430\u049b\u0442\u0438",
+                    "GMT",
+                    "\u0411\u0440\u0438\u0442\u0430\u043d\u0438\u044f \u0451\u0437\u0433\u0438 \u0432\u0430\u049b\u0442\u0438",
+                    "BST",
+                    "",
+                    "GMT",
+                }
+            },
+            { "Iceland", GMT },
+            { "Jamaica", America_Eastern },
             { "MST7MDT", America_Mountain },
+            { "NZ-CHAT", Chatham },
             { "PST8PDT", America_Pacific },
+            { "Etc/GMT0", GMT },
+            { "Hongkong", Hong_Kong },
+            { "Portugal", Europe_Western },
+            { "US/Samoa", Samoa },
             { "Asia/Aden", Arabian },
             { "Asia/Baku", Azerbaijan },
             { "Asia/Dili", East_Timor },
             { "Asia/Gaza", Europe_Eastern },
             { "Asia/Hovd", Hovd },
             { "Asia/Omsk", Omsk },
-            { "Asia/Oral", Kazakhstan_Western },
-            { "Asia/Aqtau", Kazakhstan_Western },
+            { "Etc/GMT+0", GMT },
+            { "Etc/GMT-0", GMT },
+            { "Greenwich", GMT },
+            { "Kwajalein", Marshall_Islands },
+            { "Singapore", Singapore },
+            { "US/Alaska", Alaska },
+            { "US/Hawaii", Hawaii_Aleutian },
             { "Asia/Chita", Yakutsk },
+            { "Asia/Dacca", Bangladesh },
             { "Asia/Dhaka", Bangladesh },
             { "Asia/Dubai", Gulf },
             { "Asia/Kabul", Afghanistan },
+            { "Asia/Macao", China },
             { "Asia/Macau", China },
             { "Asia/Qatar", Arabian },
             { "Asia/Seoul", Korea },
+            { "US/Arizona", America_Mountain },
+            { "US/Central", America_Central },
+            { "US/Eastern", America_Eastern },
+            { "US/Pacific", America_Pacific },
             { "Africa/Juba", Africa_Central },
             { "Africa/Lome", GMT },
-            { "Asia/Almaty", Kazakhstan_Eastern },
-            { "Asia/Aqtobe", Kazakhstan_Western },
-            { "Asia/Atyrau", Kazakhstan_Western },
             { "Asia/Beirut", Europe_Eastern },
             { "Asia/Brunei", Brunei },
             { "Asia/Harbin", China },
@@ -1245,12 +1282,20 @@ public class TimeZoneNames_uz_Cyrl extends TimeZoneNamesBundle {
             { "Asia/Saigon", Indochina },
             { "Asia/Taipei", Taipei },
             { "Asia/Tehran", Iran },
+            { "Asia/Thimbu", Bhutan },
+            { "Asia/Yangon", Cocos },
+            { "Brazil/East", Brasilia },
+            { "Brazil/West", Amazon },
             { "Europe/Kiev", Europe_Eastern },
+            { "Europe/Kyiv", Europe_Eastern },
             { "Europe/Oslo", Europe_Central },
             { "Europe/Riga", Europe_Eastern },
             { "Europe/Rome", Europe_Central },
             { "Indian/Mahe", Seychelles },
-            { "Pacific/Yap", Truk },
+            { "Pacific/Yap", Papua_New_Guinea },
+            { "US/Aleutian", Hawaii_Aleutian },
+            { "US/Michigan", America_Eastern },
+            { "US/Mountain", America_Mountain },
             { "Africa/Accra", GMT },
             { "Africa/Cairo", Europe_Eastern },
             { "Africa/Ceuta", Europe_Central },
@@ -1258,6 +1303,7 @@ public class TimeZoneNames_uz_Cyrl extends TimeZoneNamesBundle {
             { "Africa/Lagos", Africa_Western },
             { "Africa/Tunis", Europe_Central },
             { "America/Adak", Hawaii_Aleutian },
+            { "America/Atka", Hawaii_Aleutian },
             { "America/Lima", Peru },
             { "America/Nome", Alaska },
             { "Asia/Baghdad", Arabian },
@@ -1268,7 +1314,8 @@ public class TimeZoneNames_uz_Cyrl extends TimeZoneNamesBundle {
             { "Asia/Irkutsk", Irkutsk },
             { "Asia/Jakarta", Indonesia_Western },
             { "Asia/Karachi", Pakistan },
-            { "Asia/Kuching", Malaysia },
+            { "Asia/Kolkata", India },
+            { "Asia/Kuching", Brunei },
             { "Asia/Magadan", Magadan },
             { "Asia/Nicosia", Europe_Eastern },
             { "Asia/Rangoon", Myanmar },
@@ -1292,6 +1339,7 @@ public class TimeZoneNames_uz_Cyrl extends TimeZoneNamesBundle {
             { "SystemV/MST7", America_Mountain },
             { "SystemV/PST8", Pitcairn },
             { "SystemV/YST9", Gambier },
+            { "Africa/Asmara", Africa_Eastern },
             { "Africa/Asmera", Africa_Eastern },
             { "Africa/Bamako", GMT },
             { "Africa/Bangui", Africa_Western },
@@ -1319,10 +1367,14 @@ public class TimeZoneNames_uz_Cyrl extends TimeZoneNamesBundle {
             { "Asia/Katmandu", Nepal },
             { "Asia/Khandyga", Yakutsk },
             { "Asia/Makassar", Indonesia_Central },
-            { "Asia/Qostanay", Kazakhstan_Eastern },
             { "Asia/Sakhalin", Sakhalin },
             { "Asia/Tashkent", Uzbekistan },
+            { "Asia/Tel_Aviv", Israel },
             { "Asia/Ust-Nera", Vladivostok },
+            { "Australia/ACT", Australia_Eastern },
+            { "Australia/LHI", Lord_Howe },
+            { "Australia/NSW", Australia_Eastern },
+            { "Etc/Greenwich", GMT },
             { "Europe/Athens", Europe_Eastern },
             { "Europe/Berlin", Europe_Central },
             { "Europe/Dublin",
@@ -1335,7 +1387,16 @@ public class TimeZoneNames_uz_Cyrl extends TimeZoneNamesBundle {
                     "GMT",
                 }
             },
-            { "Europe/Jersey", GMT },
+            { "Europe/Jersey",
+                new String[] {
+                    "\u0413\u0440\u0438\u043d\u0432\u0438\u0447 \u0432\u0430\u049b\u0442\u0438",
+                    "GMT",
+                    "\u0411\u0440\u0438\u0442\u0430\u043d\u0438\u044f \u0451\u0437\u0433\u0438 \u0432\u0430\u049b\u0442\u0438",
+                    "BST",
+                    "",
+                    "GMT",
+                }
+            },
             { "Europe/Lisbon", Europe_Western },
             { "Europe/London",
                 new String[] {
@@ -1359,9 +1420,11 @@ public class TimeZoneNames_uz_Cyrl extends TimeZoneNamesBundle {
             { "Europe/Zurich", Europe_Central },
             { "Indian/Chagos", Indian_Ocean },
             { "Indian/Comoro", Africa_Eastern },
+            { "Pacific/Chuuk", Papua_New_Guinea },
             { "Pacific/Efate", Vanuatu },
             { "Pacific/Nauru", Nauru },
             { "Pacific/Palau", Palau },
+            { "Pacific/Samoa", Samoa },
             { "SystemV/HST10", Hawaii_Aleutian },
             { "Africa/Abidjan", GMT },
             { "Africa/Algiers", Europe_Central },
@@ -1387,14 +1450,22 @@ public class TimeZoneNames_uz_Cyrl extends TimeZoneNamesBundle {
             { "America/Panama", America_Eastern },
             { "America/Recife", Brasilia },
             { "America/Regina", America_Central },
+            { "America/Virgin", Atlantic },
+            { "Asia/Ashkhabad", Turkmenistan },
             { "Asia/Chongqing", China },
+            { "Asia/Chungking", China },
             { "Asia/Hong_Kong", Hong_Kong },
+            { "Asia/Kathmandu", Nepal },
             { "Asia/Pontianak", Indonesia_Western },
             { "Asia/Pyongyang", Korea },
-            { "Asia/Qyzylorda", Kazakhstan_Western },
             { "Asia/Samarkand", Uzbekistan },
             { "Asia/Singapore", Singapore },
             { "Asia/Vientiane", Indochina },
+            { "Atlantic/Faroe", Europe_Western },
+            { "Australia/West", Australia_Western },
+            { "Canada/Central", America_Central },
+            { "Canada/Eastern", America_Eastern },
+            { "Canada/Pacific", America_Pacific },
             { "Europe/Andorra", Europe_Central },
             { "Europe/Belfast",
                 new String[] {
@@ -1406,21 +1477,24 @@ public class TimeZoneNames_uz_Cyrl extends TimeZoneNamesBundle {
                     "GMT",
                 }
             },
+            { "Europe/Nicosia", Europe_Eastern },
             { "Europe/Tallinn", Europe_Eastern },
             { "Europe/Vatican", Europe_Central },
             { "Europe/Vilnius", Europe_Eastern },
             { "Indian/Mayotte", Africa_Eastern },
             { "Indian/Reunion", Reunion },
+            { "Mexico/General", America_Central },
             { "Pacific/Easter", Easter },
+            { "Pacific/Kanton", Phoenix_Islands },
             { "Pacific/Kosrae", Kosrae },
             { "Pacific/Majuro", Marshall_Islands },
             { "Pacific/Midway", Samoa },
             { "Pacific/Noumea", New_Caledonia },
-            { "Pacific/Ponape", Ponape },
+            { "Pacific/Ponape", Solomon },
             { "Pacific/Saipan", Chamorro },
             { "Pacific/Tahiti", Tahiti },
-            { "Pacific/Tarawa", Gilbert_Islands },
-            { "Pacific/Wallis", Wallis },
+            { "Pacific/Tarawa", Marshall_Islands },
+            { "Pacific/Wallis", Gilbert_Islands },
             { "Africa/Blantyre", Africa_Central },
             { "Africa/Djibouti", Africa_Eastern },
             { "Africa/Freetown", GMT },
@@ -1439,10 +1513,10 @@ public class TimeZoneNames_uz_Cyrl extends TimeZoneNamesBundle {
             { "America/Creston", America_Mountain },
             { "America/Curacao", Atlantic },
             { "America/Detroit", America_Eastern },
-            { "America/Godthab", Greenland_Western },
             { "America/Grenada", Atlantic },
             { "America/Iqaluit", America_Eastern },
             { "America/Jamaica", America_Eastern },
+            { "America/Knox_IN", America_Central },
             { "America/Managua", America_Central },
             { "America/Marigot", Atlantic },
             { "America/Mendoza", Argentina },
@@ -1456,25 +1530,41 @@ public class TimeZoneNames_uz_Cyrl extends TimeZoneNamesBundle {
             { "America/Yakutat", Alaska },
             { "Asia/Choibalsan", Mongolia },
             { "Asia/Phnom_Penh", Indochina },
+            { "Asia/Ulan_Bator", Mongolia },
             { "Atlantic/Azores", Azores },
             { "Atlantic/Canary", Europe_Western },
             { "Atlantic/Faeroe", Europe_Western },
             { "Australia/Eucla", Australia_CentralWestern },
+            { "Australia/North", Australia_Central },
             { "Australia/Perth", Australia_Western },
+            { "Australia/South", Australia_Central },
+            { "Canada/Atlantic", Atlantic },
+            { "Canada/Mountain", America_Mountain },
             { "Europe/Belgrade", Europe_Central },
             { "Europe/Brussels", Europe_Central },
             { "Europe/Budapest", Europe_Central },
             { "Europe/Busingen", Europe_Central },
             { "Europe/Chisinau", Europe_Eastern },
-            { "Europe/Guernsey", GMT },
+            { "Europe/Guernsey",
+                new String[] {
+                    "\u0413\u0440\u0438\u043d\u0432\u0438\u0447 \u0432\u0430\u049b\u0442\u0438",
+                    "GMT",
+                    "\u0411\u0440\u0438\u0442\u0430\u043d\u0438\u044f \u0451\u0437\u0433\u0438 \u0432\u0430\u049b\u0442\u0438",
+                    "BST",
+                    "",
+                    "GMT",
+                }
+            },
             { "Europe/Helsinki", Europe_Eastern },
             { "Europe/Sarajevo", Europe_Central },
+            { "Europe/Tiraspol", Europe_Eastern },
             { "Europe/Uzhgorod", Europe_Eastern },
-            { "Indian/Maldives", Maldives },
+            { "Indian/Maldives", French_Southern },
             { "Pacific/Chatham", Chatham },
             { "Pacific/Fakaofo", Tokelau },
             { "Pacific/Gambier", Gambier },
             { "Pacific/Norfolk", Norfolk },
+            { "Pacific/Pohnpei", Solomon },
             { "SystemV/AST4ADT", Atlantic },
             { "SystemV/CST6CDT", America_Central },
             { "SystemV/EST5EDT", America_Eastern },
@@ -1485,9 +1575,11 @@ public class TimeZoneNames_uz_Cyrl extends TimeZoneNamesBundle {
             { "Africa/Mogadishu", Africa_Eastern },
             { "America/Anguilla", Atlantic },
             { "America/Asuncion", Paraguay },
+            { "America/Atikokan", America_Eastern },
             { "America/Barbados", Atlantic },
             { "America/Dominica", Atlantic },
             { "America/Edmonton", America_Mountain },
+            { "America/Ensenada", America_Pacific },
             { "America/Miquelon", Pierre_Miquelon },
             { "America/Montreal", America_Eastern },
             { "America/Resolute", America_Central },
@@ -1497,9 +1589,11 @@ public class TimeZoneNames_uz_Cyrl extends TimeZoneNamesBundle {
             { "America/St_Kitts", Atlantic },
             { "America/St_Lucia", Atlantic },
             { "America/Winnipeg", America_Central },
+            { "Antarctica/Casey", Australia_Western },
             { "Antarctica/Davis", Davis },
             { "Antarctica/Syowa", Syowa },
             { "Antarctica/Troll", GMT },
+            { "Asia/Ho_Chi_Minh", Indochina },
             { "Asia/Krasnoyarsk", Krasnoyarsk },
             { "Asia/Novosibirsk", Novosibirsk },
             { "Asia/Ulaanbaatar", Mongolia },
@@ -1511,6 +1605,7 @@ public class TimeZoneNames_uz_Cyrl extends TimeZoneNamesBundle {
             { "Australia/Darwin", Australia_Central },
             { "Australia/Hobart", Australia_Eastern },
             { "Australia/Sydney", Australia_Eastern },
+            { "Brazil/DeNoronha", Noronha },
             { "Europe/Amsterdam", Europe_Central },
             { "Europe/Gibraltar", Europe_Central },
             { "Europe/Ljubljana", Europe_Central },
@@ -1521,6 +1616,7 @@ public class TimeZoneNames_uz_Cyrl extends TimeZoneNamesBundle {
             { "Indian/Christmas", Christmas },
             { "Indian/Kerguelen", French_Southern },
             { "Indian/Mauritius", Mauritius },
+            { "Mexico/BajaNorte", America_Pacific },
             { "Pacific/Auckland", New_Zealand },
             { "Pacific/Funafuti", Tuvalu },
             { "Pacific/Johnston", Hawaii_Aleutian },
@@ -1548,6 +1644,7 @@ public class TimeZoneNames_uz_Cyrl extends TimeZoneNamesBundle {
             { "Antarctica/Vostok", Vostok },
             { "Asia/Kuala_Lumpur", Malaysia },
             { "Asia/Novokuznetsk", Krasnoyarsk },
+            { "Chile/Continental", Chile },
             { "Europe/Bratislava", Europe_Central },
             { "Europe/Copenhagen", Europe_Central },
             { "Europe/Luxembourg", Europe_Central },
@@ -1561,6 +1658,7 @@ public class TimeZoneNames_uz_Cyrl extends TimeZoneNamesBundle {
             { "Pacific/Pago_Pago", Samoa },
             { "Pacific/Rarotonga", Cook },
             { "Pacific/Tongatapu", Tonga },
+            { "US/Indiana-Starke", America_Central },
             { "Africa/Addis_Ababa", Africa_Eastern },
             { "Africa/Brazzaville", Africa_Western },
             { "Africa/Ouagadougou", GMT },
@@ -1577,14 +1675,28 @@ public class TimeZoneNames_uz_Cyrl extends TimeZoneNamesBundle {
             { "America/St_Vincent", Atlantic },
             { "Antarctica/McMurdo", New_Zealand },
             { "Antarctica/Rothera", Rothera },
+            { "Asia/Ujung_Pandang", Indonesia_Central },
             { "Asia/Yekaterinburg", Yekaterinburg },
             { "Atlantic/Jan_Mayen", Europe_Central },
             { "Atlantic/Reykjavik", GMT },
             { "Atlantic/St_Helena", GMT },
             { "Australia/Adelaide", Australia_Central },
             { "Australia/Brisbane", Australia_Eastern },
+            { "Australia/Canberra", Australia_Eastern },
             { "Australia/Lindeman", Australia_Eastern },
-            { "Europe/Isle_of_Man", GMT },
+            { "Australia/Tasmania", Australia_Eastern },
+            { "Australia/Victoria", Australia_Eastern },
+            { "Chile/EasterIsland", Easter },
+            { "Europe/Isle_of_Man",
+                new String[] {
+                    "\u0413\u0440\u0438\u043d\u0432\u0438\u0447 \u0432\u0430\u049b\u0442\u0438",
+                    "GMT",
+                    "\u0411\u0440\u0438\u0442\u0430\u043d\u0438\u044f \u0451\u0437\u0433\u0438 \u0432\u0430\u049b\u0442\u0438",
+                    "BST",
+                    "",
+                    "GMT",
+                }
+            },
             { "Europe/Kaliningrad", Europe_Eastern },
             { "Pacific/Kiritimati", Line_Islands },
             { "Africa/Johannesburg", Africa_Southern },
@@ -1602,6 +1714,8 @@ public class TimeZoneNames_uz_Cyrl extends TimeZoneNamesBundle {
             { "Atlantic/Cape_Verde", Cape_Verde },
             { "Australia/Lord_Howe", Lord_Howe },
             { "Australia/Melbourne", Australia_Eastern },
+            { "Canada/Newfoundland", Newfoundland },
+            { "Canada/Saskatchewan", America_Central },
             { "Indian/Antananarivo", Africa_Eastern },
             { "Pacific/Guadalcanal", Solomon },
             { "Africa/Dar_es_Salaam", Africa_Eastern },
@@ -1612,9 +1726,11 @@ public class TimeZoneNames_uz_Cyrl extends TimeZoneNamesBundle {
             { "America/Dawson_Creek", America_Mountain },
             { "America/Indiana/Knox", America_Central },
             { "America/Rankin_Inlet", America_Central },
-            { "America/Scoresbysund", Greenland_Eastern },
+            { "America/Santa_Isabel", America_Pacific },
             { "Antarctica/Macquarie", Australia_Eastern },
-            { "Pacific/Port_Moresby", Papua_New_Guinea },
+            { "Australia/Queensland", Australia_Eastern },
+            { "Australia/Yancowinna", Australia_Central },
+            { "Pacific/Port_Moresby", DumontDUrville },
             { "America/Cambridge_Bay", America_Mountain },
             { "America/Ciudad_Juarez", America_Mountain },
             { "America/Coral_Harbour", America_Eastern },
@@ -1629,9 +1745,12 @@ public class TimeZoneNames_uz_Cyrl extends TimeZoneNamesBundle {
             { "America/Bahia_Banderas", America_Central },
             { "America/Port-au-Prince", America_Eastern },
             { "Atlantic/South_Georgia", South_Georgia },
+            { "America/Argentina/Jujuy", Argentina },
             { "America/Argentina/Salta", Argentina },
             { "America/Indiana/Marengo", America_Eastern },
             { "America/Indiana/Winamac", America_Eastern },
+            { "America/Argentina/Cordoba", Argentina },
+            { "America/Argentina/Mendoza", Argentina },
             { "America/Argentina/Tucuman", Argentina },
             { "America/Argentina/Ushuaia", Argentina },
             { "America/Indiana/Tell_City", America_Central },
@@ -1641,10 +1760,14 @@ public class TimeZoneNames_uz_Cyrl extends TimeZoneNamesBundle {
             { "America/Argentina/San_Juan", Argentina },
             { "America/Argentina/San_Luis", Argentina },
             { "America/Indiana/Petersburg", America_Eastern },
+            { "America/Argentina/Catamarca", Argentina },
+            { "America/Kentucky/Louisville", America_Eastern },
             { "America/Kentucky/Monticello", America_Eastern },
             { "America/North_Dakota/Beulah", America_Central },
             { "America/North_Dakota/Center", America_Central },
             { "timezone.excity.Etc/Unknown", "\u041d\u043e\u043c\u0430\u044a\u043b\u0443\u043c" },
+            { "America/Indiana/Indianapolis", America_Eastern },
+            { "America/Argentina/Buenos_Aires", Argentina },
             { "America/Argentina/Rio_Gallegos", Argentina },
             { "America/North_Dakota/New_Salem", America_Central },
             { "timezone.excity.America/Lower_Princes", "Lower Prince\u02bcs Quarter" },
